# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: yandex/cloud/mdb/clickhouse/v1/config/clickhouse.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from yandex.cloud import validation_pb2 as yandex_dot_cloud_dot_validation__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n6yandex/cloud/mdb/clickhouse/v1/config/clickhouse.proto\x12%yandex.cloud.mdb.clickhouse.v1.config\x1a\x1egoogle/protobuf/wrappers.proto\x1a\x1dyandex/cloud/validation.proto\"\xd1k\n\x10\x43lickhouseConfig\x12S\n\tlog_level\x18\x01 \x01(\x0e\x32@.yandex.cloud.mdb.clickhouse.v1.config.ClickhouseConfig.LogLevel\x12U\n\nmerge_tree\x18\x02 \x01(\x0b\x32\x41.yandex.cloud.mdb.clickhouse.v1.config.ClickhouseConfig.MergeTree\x12X\n\x0b\x63ompression\x18\x03 \x03(\x0b\x32\x43.yandex.cloud.mdb.clickhouse.v1.config.ClickhouseConfig.Compression\x12`\n\x0c\x64ictionaries\x18\x04 \x03(\x0b\x32J.yandex.cloud.mdb.clickhouse.v1.config.ClickhouseConfig.ExternalDictionary\x12_\n\x0fgraphite_rollup\x18\x05 \x03(\x0b\x32\x46.yandex.cloud.mdb.clickhouse.v1.config.ClickhouseConfig.GraphiteRollup\x12L\n\x05kafka\x18# \x01(\x0b\x32=.yandex.cloud.mdb.clickhouse.v1.config.ClickhouseConfig.Kafka\x12X\n\x0ckafka_topics\x18$ \x03(\x0b\x32\x42.yandex.cloud.mdb.clickhouse.v1.config.ClickhouseConfig.KafkaTopic\x12R\n\x08rabbitmq\x18% \x01(\x0b\x32@.yandex.cloud.mdb.clickhouse.v1.config.ClickhouseConfig.Rabbitmq\x12>\n\x0fmax_connections\x18\x06 \x01(\x0b\x32\x1b.google.protobuf.Int64ValueB\x08\xfa\xc7\x31\x04>=10\x12\x45\n\x16max_concurrent_queries\x18\x07 \x01(\x0b\x32\x1b.google.protobuf.Int64ValueB\x08\xfa\xc7\x31\x04>=10\x12\x37\n\x12keep_alive_timeout\x18\x08 \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12<\n\x17uncompressed_cache_size\x18\t \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12<\n\x0fmark_cache_size\x18\n \x01(\x0b\x32\x1b.google.protobuf.Int64ValueB\x06\xfa\xc7\x31\x02>0\x12;\n\x16max_table_size_to_drop\x18\x0b \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12?\n\x1amax_partition_size_to_drop\x18\r \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12M\n$builtin_dictionaries_reload_interval\x18\x0c \x01(\x0b\x32\x1b.google.protobuf.Int64ValueB\x02\x18\x01\x12\x10\n\x08timezone\x18\x0e \x01(\t\x12\x33\n\x0fgeobase_enabled\x18\x42 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12\x13\n\x0bgeobase_uri\x18\x0f \x01(\t\x12=\n\x18query_log_retention_size\x18\x10 \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12=\n\x18query_log_retention_time\x18\x11 \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12<\n\x18query_thread_log_enabled\x18\x12 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12\x44\n\x1fquery_thread_log_retention_size\x18\x13 \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12\x44\n\x1fquery_thread_log_retention_time\x18\x14 \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12<\n\x17part_log_retention_size\x18\x15 \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12<\n\x17part_log_retention_time\x18\x16 \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12\x36\n\x12metric_log_enabled\x18\x17 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12>\n\x19metric_log_retention_size\x18\x18 \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12>\n\x19metric_log_retention_time\x18\x19 \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12\x35\n\x11trace_log_enabled\x18\x1a \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12=\n\x18trace_log_retention_size\x18\x1b \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12=\n\x18trace_log_retention_time\x18\x1c \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12\x34\n\x10text_log_enabled\x18\x1d \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12<\n\x17text_log_retention_size\x18\x1e \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12<\n\x17text_log_retention_time\x18\x1f \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12X\n\x0etext_log_level\x18  \x01(\x0e\x32@.yandex.cloud.mdb.clickhouse.v1.config.ClickhouseConfig.LogLevel\x12\x42\n\x1eopentelemetry_span_log_enabled\x18* \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12S\n%opentelemetry_span_log_retention_size\x18\x37 \x01(\x0b\x32\x1b.google.protobuf.Int64ValueB\x07\xfa\xc7\x31\x03>=0\x12S\n%opentelemetry_span_log_retention_time\x18\x38 \x01(\x0b\x32\x1b.google.protobuf.Int64ValueB\x07\xfa\xc7\x31\x03>=0\x12;\n\x17query_views_log_enabled\x18\x31 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12L\n\x1equery_views_log_retention_size\x18\x32 \x01(\x0b\x32\x1b.google.protobuf.Int64ValueB\x07\xfa\xc7\x31\x03>=0\x12L\n\x1equery_views_log_retention_time\x18\x33 \x01(\x0b\x32\x1b.google.protobuf.Int64ValueB\x07\xfa\xc7\x31\x03>=0\x12\x43\n\x1f\x61synchronous_metric_log_enabled\x18\x34 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12T\n&asynchronous_metric_log_retention_size\x18\x35 \x01(\x0b\x32\x1b.google.protobuf.Int64ValueB\x07\xfa\xc7\x31\x03>=0\x12T\n&asynchronous_metric_log_retention_time\x18\x36 \x01(\x0b\x32\x1b.google.protobuf.Int64ValueB\x07\xfa\xc7\x31\x03>=0\x12\x37\n\x13session_log_enabled\x18\x39 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12H\n\x1asession_log_retention_size\x18: \x01(\x0b\x32\x1b.google.protobuf.Int64ValueB\x07\xfa\xc7\x31\x03>=0\x12H\n\x1asession_log_retention_time\x18; \x01(\x0b\x32\x1b.google.protobuf.Int64ValueB\x07\xfa\xc7\x31\x03>=0\x12\x39\n\x15zookeeper_log_enabled\x18< \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12J\n\x1czookeeper_log_retention_size\x18= \x01(\x0b\x32\x1b.google.protobuf.Int64ValueB\x07\xfa\xc7\x31\x03>=0\x12J\n\x1czookeeper_log_retention_time\x18> \x01(\x0b\x32\x1b.google.protobuf.Int64ValueB\x07\xfa\xc7\x31\x03>=0\x12\x43\n\x1f\x61synchronous_insert_log_enabled\x18? \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12T\n&asynchronous_insert_log_retention_size\x18@ \x01(\x0b\x32\x1b.google.protobuf.Int64ValueB\x07\xfa\xc7\x31\x03>=0\x12T\n&asynchronous_insert_log_retention_time\x18\x41 \x01(\x0b\x32\x1b.google.protobuf.Int64ValueB\x07\xfa\xc7\x31\x03>=0\x12\x41\n\x14\x62\x61\x63kground_pool_size\x18! \x01(\x0b\x32\x1b.google.protobuf.Int64ValueB\x06\xfa\xc7\x31\x02>0\x12Z\n-background_merges_mutations_concurrency_ratio\x18\x30 \x01(\x0b\x32\x1b.google.protobuf.Int64ValueB\x06\xfa\xc7\x31\x02>0\x12J\n\x1d\x62\x61\x63kground_schedule_pool_size\x18\" \x01(\x0b\x32\x1b.google.protobuf.Int64ValueB\x06\xfa\xc7\x31\x02>0\x12I\n\x1c\x62\x61\x63kground_fetches_pool_size\x18& \x01(\x0b\x32\x1b.google.protobuf.Int64ValueB\x06\xfa\xc7\x31\x02>0\x12\x46\n\x19\x62\x61\x63kground_move_pool_size\x18\' \x01(\x0b\x32\x1b.google.protobuf.Int64ValueB\x06\xfa\xc7\x31\x02>0\x12V\n)background_distributed_schedule_pool_size\x18( \x01(\x0b\x32\x1b.google.protobuf.Int64ValueB\x06\xfa\xc7\x31\x02>0\x12W\n*background_buffer_flush_schedule_pool_size\x18) \x01(\x0b\x32\x1b.google.protobuf.Int64ValueB\x06\xfa\xc7\x31\x02>0\x12Y\n,background_message_broker_schedule_pool_size\x18. \x01(\x0b\x32\x1b.google.protobuf.Int64ValueB\x06\xfa\xc7\x31\x02>0\x12H\n\x1b\x62\x61\x63kground_common_pool_size\x18/ \x01(\x0b\x32\x1b.google.protobuf.Int64ValueB\x06\xfa\xc7\x31\x02>0\x12\x36\n\x10\x64\x65\x66\x61ult_database\x18+ \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12?\n\x1atotal_memory_profiler_step\x18, \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12M\n\'total_memory_tracker_sample_probability\x18- \x01(\x0b\x32\x1c.google.protobuf.DoubleValue\x12m\n\x13query_masking_rules\x18\x43 \x03(\x0b\x32H.yandex.cloud.mdb.clickhouse.v1.config.ClickhouseConfig.QueryMaskingRuleB\x06\x82\xc8\x31\x02>0\x12:\n\x16\x64ictionaries_lazy_load\x18\x44 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12W\n\x0bquery_cache\x18\x45 \x01(\x0b\x32\x42.yandex.cloud.mdb.clickhouse.v1.config.ClickhouseConfig.QueryCache\x1a\xd4\x0f\n\tMergeTree\x12\x44\n\x1freplicated_deduplication_window\x18\x01 \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12L\n\'replicated_deduplication_window_seconds\x18\x02 \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12:\n\x15parts_to_delay_insert\x18\x03 \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12:\n\x15parts_to_throw_insert\x18\x04 \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12\x43\n\x1einactive_parts_to_delay_insert\x18\t \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12\x43\n\x1einactive_parts_to_throw_insert\x18\n \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12\x43\n\x1emax_replicated_merges_in_queue\x18\x05 \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12^\n9number_of_free_entries_in_pool_to_lower_max_size_of_merge\x18\x06 \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12L\n\'max_bytes_to_merge_at_min_space_in_pool\x18\x07 \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12L\n\'max_bytes_to_merge_at_max_space_in_pool\x18\x08 \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12<\n\x17min_bytes_for_wide_part\x18\x0b \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12;\n\x16min_rows_for_wide_part\x18\x0c \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12\x37\n\x13ttl_only_drop_parts\x18\r \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12I\n%allow_remote_fs_zero_copy_replication\x18\x0e \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12;\n\x16merge_with_ttl_timeout\x18\x0f \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12I\n$merge_with_recompression_ttl_timeout\x18\x10 \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12\x37\n\x12max_parts_in_total\x18\x11 \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12J\n%max_number_of_merges_with_ttl_in_pool\x18\x12 \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12\x39\n\x14\x63leanup_delay_period\x18\x13 \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12W\n2number_of_free_entries_in_pool_to_execute_mutation\x18\x14 \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12R\n$max_avg_part_size_for_too_many_parts\x18\x15 \x01(\x0b\x32\x1b.google.protobuf.Int64ValueB\x07\xfa\xc7\x31\x03>=0\x12L\n\x1emin_age_to_force_merge_seconds\x18\x16 \x01(\x0b\x32\x1b.google.protobuf.Int64ValueB\x07\xfa\xc7\x31\x03>=0\x12L\n(min_age_to_force_merge_on_partition_only\x18\x17 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12\x45\n\x18merge_selecting_sleep_ms\x18\x18 \x01(\x0b\x32\x1b.google.protobuf.Int64ValueB\x06\xfa\xc7\x31\x02>0\x12\x41\n\x14merge_max_block_size\x18\x19 \x01(\x0b\x32\x1b.google.protobuf.Int64ValueB\x06\xfa\xc7\x31\x02>0\x12\x42\n\x1e\x63heck_sample_column_is_correct\x18\x1a \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12J\n\x1cmax_merge_selecting_sleep_ms\x18\x1b \x01(\x0b\x32\x1b.google.protobuf.Int64ValueB\x07\xfa\xc7\x31\x03>=0\x12\x46\n\x18max_cleanup_delay_period\x18\x1c \x01(\x0b\x32\x1b.google.protobuf.Int64ValueB\x07\xfa\xc7\x31\x03>=0\x1a\xa0\r\n\x05Kafka\x12i\n\x11security_protocol\x18\x01 \x01(\x0e\x32N.yandex.cloud.mdb.clickhouse.v1.config.ClickhouseConfig.Kafka.SecurityProtocol\x12\x63\n\x0esasl_mechanism\x18\x02 \x01(\x0e\x32K.yandex.cloud.mdb.clickhouse.v1.config.ClickhouseConfig.Kafka.SaslMechanism\x12\x15\n\rsasl_username\x18\x03 \x01(\t\x12\x15\n\rsasl_password\x18\x04 \x01(\t\x12G\n#enable_ssl_certificate_verification\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12\x42\n\x14max_poll_interval_ms\x18\x06 \x01(\x0b\x32\x1b.google.protobuf.Int64ValueB\x07\xfa\xc7\x31\x03>=0\x12@\n\x12session_timeout_ms\x18\x07 \x01(\x0b\x32\x1b.google.protobuf.Int64ValueB\x07\xfa\xc7\x31\x03>=0\x12R\n\x05\x64\x65\x62ug\x18\x08 \x01(\x0e\x32\x43.yandex.cloud.mdb.clickhouse.v1.config.ClickhouseConfig.Kafka.Debug\x12h\n\x11\x61uto_offset_reset\x18\t \x01(\x0e\x32M.yandex.cloud.mdb.clickhouse.v1.config.ClickhouseConfig.Kafka.AutoOffsetReset\"\xb7\x01\n\x10SecurityProtocol\x12!\n\x1dSECURITY_PROTOCOL_UNSPECIFIED\x10\x00\x12\x1f\n\x1bSECURITY_PROTOCOL_PLAINTEXT\x10\x01\x12\x19\n\x15SECURITY_PROTOCOL_SSL\x10\x02\x12$\n SECURITY_PROTOCOL_SASL_PLAINTEXT\x10\x03\x12\x1e\n\x1aSECURITY_PROTOCOL_SASL_SSL\x10\x04\"\xa8\x01\n\rSaslMechanism\x12\x1e\n\x1aSASL_MECHANISM_UNSPECIFIED\x10\x00\x12\x19\n\x15SASL_MECHANISM_GSSAPI\x10\x01\x12\x18\n\x14SASL_MECHANISM_PLAIN\x10\x02\x12 \n\x1cSASL_MECHANISM_SCRAM_SHA_256\x10\x03\x12 \n\x1cSASL_MECHANISM_SCRAM_SHA_512\x10\x04\"\x99\x03\n\x05\x44\x65\x62ug\x12\x15\n\x11\x44\x45\x42UG_UNSPECIFIED\x10\x00\x12\x11\n\rDEBUG_GENERIC\x10\x01\x12\x10\n\x0c\x44\x45\x42UG_BROKER\x10\x02\x12\x0f\n\x0b\x44\x45\x42UG_TOPIC\x10\x03\x12\x12\n\x0e\x44\x45\x42UG_METADATA\x10\x04\x12\x11\n\rDEBUG_FEATURE\x10\x05\x12\x0f\n\x0b\x44\x45\x42UG_QUEUE\x10\x06\x12\r\n\tDEBUG_MSG\x10\x07\x12\x12\n\x0e\x44\x45\x42UG_PROTOCOL\x10\x08\x12\x0e\n\nDEBUG_CGRP\x10\t\x12\x12\n\x0e\x44\x45\x42UG_SECURITY\x10\n\x12\x0f\n\x0b\x44\x45\x42UG_FETCH\x10\x0b\x12\x15\n\x11\x44\x45\x42UG_INTERCEPTOR\x10\x0c\x12\x10\n\x0c\x44\x45\x42UG_PLUGIN\x10\r\x12\x12\n\x0e\x44\x45\x42UG_CONSUMER\x10\x0e\x12\x0f\n\x0b\x44\x45\x42UG_ADMIN\x10\x0f\x12\r\n\tDEBUG_EOS\x10\x10\x12\x0e\n\nDEBUG_MOCK\x10\x11\x12\x12\n\x0e\x44\x45\x42UG_ASSIGNOR\x10\x12\x12\x0e\n\nDEBUG_CONF\x10\x13\x12\x13\n\x0f\x44\x45\x42UG_TELEMETRY\x10\x14\x12\r\n\tDEBUG_ALL\x10\x15\"\x8a\x02\n\x0f\x41utoOffsetReset\x12!\n\x1d\x41UTO_OFFSET_RESET_UNSPECIFIED\x10\x00\x12\x1e\n\x1a\x41UTO_OFFSET_RESET_SMALLEST\x10\x01\x12\x1e\n\x1a\x41UTO_OFFSET_RESET_EARLIEST\x10\x02\x12\x1f\n\x1b\x41UTO_OFFSET_RESET_BEGINNING\x10\x03\x12\x1d\n\x19\x41UTO_OFFSET_RESET_LARGEST\x10\x04\x12\x1c\n\x18\x41UTO_OFFSET_RESET_LATEST\x10\x05\x12\x19\n\x15\x41UTO_OFFSET_RESET_END\x10\x06\x12\x1b\n\x17\x41UTO_OFFSET_RESET_ERROR\x10\x07\x1aw\n\nKafkaTopic\x12\x12\n\x04name\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\x12U\n\x08settings\x18\x02 \x01(\x0b\x32=.yandex.cloud.mdb.clickhouse.v1.config.ClickhouseConfig.KafkaB\x04\xe8\xc7\x31\x01\x1a=\n\x08Rabbitmq\x12\x10\n\x08username\x18\x01 \x01(\t\x12\x10\n\x08password\x18\x02 \x01(\t\x12\r\n\x05vhost\x18\x03 \x01(\t\x1a\x90\x02\n\x0b\x43ompression\x12Z\n\x06method\x18\x01 \x01(\x0e\x32J.yandex.cloud.mdb.clickhouse.v1.config.ClickhouseConfig.Compression.Method\x12\x1e\n\rmin_part_size\x18\x02 \x01(\x03\x42\x07\xfa\xc7\x31\x03>=1\x12\x1b\n\x13min_part_size_ratio\x18\x03 \x01(\x01\x12\x33\n\x05level\x18\x04 \x01(\x0b\x32\x1b.google.protobuf.Int64ValueB\x07\xfa\xc7\x31\x03>=0\"3\n\x06Method\x12\x16\n\x12METHOD_UNSPECIFIED\x10\x00\x12\x07\n\x03LZ4\x10\x01\x12\x08\n\x04ZSTD\x10\x02\x1a\xfc\x1c\n\x12\x45xternalDictionary\x12\x12\n\x04name\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\x12m\n\tstructure\x18\x02 \x01(\x0b\x32T.yandex.cloud.mdb.clickhouse.v1.config.ClickhouseConfig.ExternalDictionary.StructureB\x04\xe8\xc7\x31\x01\x12g\n\x06layout\x18\x03 \x01(\x0b\x32Q.yandex.cloud.mdb.clickhouse.v1.config.ClickhouseConfig.ExternalDictionary.LayoutB\x04\xe8\xc7\x31\x01\x12\x18\n\x0e\x66ixed_lifetime\x18\x04 \x01(\x03H\x00\x12j\n\x0elifetime_range\x18\x05 \x01(\x0b\x32P.yandex.cloud.mdb.clickhouse.v1.config.ClickhouseConfig.ExternalDictionary.RangeH\x00\x12l\n\x0bhttp_source\x18\x06 \x01(\x0b\x32U.yandex.cloud.mdb.clickhouse.v1.config.ClickhouseConfig.ExternalDictionary.HttpSourceH\x01\x12n\n\x0cmysql_source\x18\x07 \x01(\x0b\x32V.yandex.cloud.mdb.clickhouse.v1.config.ClickhouseConfig.ExternalDictionary.MysqlSourceH\x01\x12x\n\x11\x63lickhouse_source\x18\x08 \x01(\x0b\x32[.yandex.cloud.mdb.clickhouse.v1.config.ClickhouseConfig.ExternalDictionary.ClickhouseSourceH\x01\x12r\n\x0emongodb_source\x18\t \x01(\x0b\x32X.yandex.cloud.mdb.clickhouse.v1.config.ClickhouseConfig.ExternalDictionary.MongodbSourceH\x01\x12x\n\x11postgresql_source\x18\n \x01(\x0b\x32[.yandex.cloud.mdb.clickhouse.v1.config.ClickhouseConfig.ExternalDictionary.PostgresqlSourceH\x01\x1a\xd7\x01\n\nHttpSource\x12\x11\n\x03url\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\x12\x14\n\x06\x66ormat\x18\x02 \x01(\tB\x04\xe8\xc7\x31\x01\x12m\n\x07headers\x18\x03 \x03(\x0b\x32\\.yandex.cloud.mdb.clickhouse.v1.config.ClickhouseConfig.ExternalDictionary.HttpSource.Header\x1a\x31\n\x06Header\x12\x12\n\x04name\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\x12\x13\n\x05value\x18\x02 \x01(\tB\x04\xe8\xc7\x31\x01\x1a\xff\x03\n\x0bMysqlSource\x12\x10\n\x02\x64\x62\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\x12\x13\n\x05table\x18\x02 \x01(\tB\x04\xe8\xc7\x31\x01\x12\x19\n\x04port\x18\x03 \x01(\x03\x42\x0b\xfa\xc7\x31\x07\x30-65535\x12\x0c\n\x04user\x18\x04 \x01(\t\x12\x10\n\x08password\x18\x05 \x01(\t\x12x\n\x08replicas\x18\x06 \x03(\x0b\x32^.yandex.cloud.mdb.clickhouse.v1.config.ClickhouseConfig.ExternalDictionary.MysqlSource.ReplicaB\x06\x82\xc8\x31\x02>0\x12\r\n\x05where\x18\x07 \x01(\t\x12\x18\n\x10invalidate_query\x18\x08 \x01(\t\x12\x34\n\x10\x63lose_connection\x18\t \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12\x34\n\x10share_connection\x18\n \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x1a\x7f\n\x07Replica\x12\x1b\n\x04host\x18\x01 \x01(\tB\r\xe8\xc7\x31\x01\x8a\xc8\x31\x05<=253\x12\x1c\n\x08priority\x18\x02 \x01(\x03\x42\n\xe8\xc7\x31\x01\xfa\xc7\x31\x02>0\x12\x19\n\x04port\x18\x03 \x01(\x03\x42\x0b\xfa\xc7\x31\x07\x30-65535\x12\x0c\n\x04user\x18\x04 \x01(\t\x12\x10\n\x08password\x18\x05 \x01(\t\x1a\xce\x01\n\x10\x43lickhouseSource\x12\x10\n\x02\x64\x62\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\x12\x13\n\x05table\x18\x02 \x01(\tB\x04\xe8\xc7\x31\x01\x12\x17\n\x04host\x18\x03 \x01(\tB\t\x8a\xc8\x31\x05<=253\x12\x19\n\x04port\x18\x04 \x01(\x03\x42\x0b\xfa\xc7\x31\x07\x30-65535\x12\x12\n\x04user\x18\x05 \x01(\tB\x04\xe8\xc7\x31\x01\x12\x10\n\x08password\x18\x06 \x01(\t\x12\r\n\x05where\x18\x07 \x01(\t\x12*\n\x06secure\x18\x08 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x1a\xa6\x01\n\rMongodbSource\x12\x10\n\x02\x64\x62\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\x12\x18\n\ncollection\x18\x02 \x01(\tB\x04\xe8\xc7\x31\x01\x12\x17\n\x04host\x18\x03 \x01(\tB\t\x8a\xc8\x31\x05<=253\x12\x19\n\x04port\x18\x04 \x01(\x03\x42\x0b\xfa\xc7\x31\x07\x30-65535\x12\x12\n\x04user\x18\x05 \x01(\tB\x04\xe8\xc7\x31\x01\x12\x10\n\x08password\x18\x06 \x01(\t\x12\x0f\n\x07options\x18\x07 \x01(\t\x1a\x8b\x03\n\x10PostgresqlSource\x12\x10\n\x02\x64\x62\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\x12\x13\n\x05table\x18\x02 \x01(\tB\x04\xe8\xc7\x31\x01\x12\x15\n\x05hosts\x18\x03 \x03(\tB\x06\x82\xc8\x31\x02>0\x12\x19\n\x04port\x18\x04 \x01(\x03\x42\x0b\xfa\xc7\x31\x07\x30-65535\x12\x12\n\x04user\x18\x05 \x01(\tB\x04\xe8\xc7\x31\x01\x12\x10\n\x08password\x18\x06 \x01(\t\x12\x18\n\x10invalidate_query\x18\x07 \x01(\t\x12u\n\x08ssl_mode\x18\x08 \x01(\x0e\x32\x63.yandex.cloud.mdb.clickhouse.v1.config.ClickhouseConfig.ExternalDictionary.PostgresqlSource.SslMode\"g\n\x07SslMode\x12\x18\n\x14SSL_MODE_UNSPECIFIED\x10\x00\x12\x0b\n\x07\x44ISABLE\x10\x01\x12\t\n\x05\x41LLOW\x10\x02\x12\n\n\x06PREFER\x10\x03\x12\r\n\tVERIFY_CA\x10\x04\x12\x0f\n\x0bVERIFY_FULL\x10\x05\x1a\xde\x06\n\tStructure\x12\x63\n\x02id\x18\x01 \x01(\x0b\x32W.yandex.cloud.mdb.clickhouse.v1.config.ClickhouseConfig.ExternalDictionary.Structure.Id\x12\x65\n\x03key\x18\x03 \x01(\x0b\x32X.yandex.cloud.mdb.clickhouse.v1.config.ClickhouseConfig.ExternalDictionary.Structure.Key\x12q\n\trange_min\x18\x04 \x01(\x0b\x32^.yandex.cloud.mdb.clickhouse.v1.config.ClickhouseConfig.ExternalDictionary.Structure.Attribute\x12q\n\trange_max\x18\x05 \x01(\x0b\x32^.yandex.cloud.mdb.clickhouse.v1.config.ClickhouseConfig.ExternalDictionary.Structure.Attribute\x12z\n\nattributes\x18\x02 \x03(\x0b\x32^.yandex.cloud.mdb.clickhouse.v1.config.ClickhouseConfig.ExternalDictionary.Structure.AttributeB\x06\x82\xc8\x31\x02>0\x1a\x84\x01\n\tAttribute\x12\x12\n\x04name\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\x12\x12\n\x04type\x18\x02 \x01(\tB\x04\xe8\xc7\x31\x01\x12\x12\n\nnull_value\x18\x03 \x01(\t\x12\x12\n\nexpression\x18\x04 \x01(\t\x12\x14\n\x0chierarchical\x18\x05 \x01(\x08\x12\x11\n\tinjective\x18\x06 \x01(\x08\x1a\x18\n\x02Id\x12\x12\n\x04name\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\x1a\x81\x01\n\x03Key\x12z\n\nattributes\x18\x01 \x03(\x0b\x32^.yandex.cloud.mdb.clickhouse.v1.config.ClickhouseConfig.ExternalDictionary.Structure.AttributeB\x06\x82\xc8\x31\x02>0\x1a\xa3\x02\n\x06Layout\x12j\n\x04type\x18\x01 \x01(\x0e\x32V.yandex.cloud.mdb.clickhouse.v1.config.ClickhouseConfig.ExternalDictionary.Layout.TypeB\x04\xe8\xc7\x31\x01\x12\x15\n\rsize_in_cells\x18\x02 \x01(\x03\x12\x16\n\x0emax_array_size\x18\x03 \x01(\x03\"~\n\x04Type\x12\x14\n\x10TYPE_UNSPECIFIED\x10\x00\x12\x08\n\x04\x46LAT\x10\x01\x12\n\n\x06HASHED\x10\x02\x12\x16\n\x12\x43OMPLEX_KEY_HASHED\x10\x03\x12\x10\n\x0cRANGE_HASHED\x10\x04\x12\t\n\x05\x43\x41\x43HE\x10\x05\x12\x15\n\x11\x43OMPLEX_KEY_CACHE\x10\x06\x1a!\n\x05Range\x12\x0b\n\x03min\x18\x01 \x01(\x03\x12\x0b\n\x03max\x18\x02 \x01(\x03\x42\x10\n\x08lifetime\x12\x04\xc0\xc1\x31\x01\x42\x0e\n\x06source\x12\x04\xc0\xc1\x31\x01\x1a\xe1\x03\n\x0eGraphiteRollup\x12\x12\n\x04name\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\x12h\n\x08patterns\x18\x02 \x03(\x0b\x32N.yandex.cloud.mdb.clickhouse.v1.config.ClickhouseConfig.GraphiteRollup.PatternB\x06\x82\xc8\x31\x02>0\x12\x18\n\x10path_column_name\x18\x03 \x01(\t\x12\x18\n\x10time_column_name\x18\x04 \x01(\t\x12\x19\n\x11value_column_name\x18\x05 \x01(\t\x12\x1b\n\x13version_column_name\x18\x06 \x01(\t\x1a\xe4\x01\n\x07Pattern\x12\x0e\n\x06regexp\x18\x01 \x01(\t\x12\x16\n\x08\x66unction\x18\x02 \x01(\tB\x04\xe8\xc7\x31\x01\x12s\n\tretention\x18\x03 \x03(\x0b\x32X.yandex.cloud.mdb.clickhouse.v1.config.ClickhouseConfig.GraphiteRollup.Pattern.RetentionB\x06\x82\xc8\x31\x02>0\x1a<\n\tRetention\x12\x14\n\x03\x61ge\x18\x01 \x01(\x03\x42\x07\xfa\xc7\x31\x03>=0\x12\x19\n\tprecision\x18\x02 \x01(\x03\x42\x06\xfa\xc7\x31\x02>0\x1aG\n\x10QueryMaskingRule\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x14\n\x06regexp\x18\x02 \x01(\tB\x04\xe8\xc7\x31\x01\x12\x0f\n\x07replace\x18\x03 \x01(\t\x1a\x95\x02\n\nQueryCache\x12?\n\x11max_size_in_bytes\x18\x01 \x01(\x0b\x32\x1b.google.protobuf.Int64ValueB\x07\xfa\xc7\x31\x03>=0\x12\x39\n\x0bmax_entries\x18\x02 \x01(\x0b\x32\x1b.google.protobuf.Int64ValueB\x07\xfa\xc7\x31\x03>=0\x12\x45\n\x17max_entry_size_in_bytes\x18\x03 \x01(\x0b\x32\x1b.google.protobuf.Int64ValueB\x07\xfa\xc7\x31\x03>=0\x12\x44\n\x16max_entry_size_in_rows\x18\x04 \x01(\x0b\x32\x1b.google.protobuf.Int64ValueB\x07\xfa\xc7\x31\x03>=0\"d\n\x08LogLevel\x12\x19\n\x15LOG_LEVEL_UNSPECIFIED\x10\x00\x12\t\n\x05TRACE\x10\x01\x12\t\n\x05\x44\x45\x42UG\x10\x02\x12\x0f\n\x0bINFORMATION\x10\x03\x12\x0b\n\x07WARNING\x10\x04\x12\t\n\x05\x45RROR\x10\x05\"\x8d\x02\n\x13\x43lickhouseConfigSet\x12W\n\x10\x65\x66\x66\x65\x63tive_config\x18\x01 \x01(\x0b\x32\x37.yandex.cloud.mdb.clickhouse.v1.config.ClickhouseConfigB\x04\xe8\xc7\x31\x01\x12L\n\x0buser_config\x18\x02 \x01(\x0b\x32\x37.yandex.cloud.mdb.clickhouse.v1.config.ClickhouseConfig\x12O\n\x0e\x64\x65\x66\x61ult_config\x18\x03 \x01(\x0b\x32\x37.yandex.cloud.mdb.clickhouse.v1.config.ClickhouseConfigB\x81\x01\n)yandex.cloud.api.mdb.clickhouse.v1.configZTgithub.com/yandex-cloud/go-genproto/yandex/cloud/mdb/clickhouse/v1/config;clickhouseb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.mdb.clickhouse.v1.config.clickhouse_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n)yandex.cloud.api.mdb.clickhouse.v1.configZTgithub.com/yandex-cloud/go-genproto/yandex/cloud/mdb/clickhouse/v1/config;clickhouse'
  _CLICKHOUSECONFIG_MERGETREE.fields_by_name['max_avg_part_size_for_too_many_parts']._options = None
  _CLICKHOUSECONFIG_MERGETREE.fields_by_name['max_avg_part_size_for_too_many_parts']._serialized_options = b'\372\3071\003>=0'
  _CLICKHOUSECONFIG_MERGETREE.fields_by_name['min_age_to_force_merge_seconds']._options = None
  _CLICKHOUSECONFIG_MERGETREE.fields_by_name['min_age_to_force_merge_seconds']._serialized_options = b'\372\3071\003>=0'
  _CLICKHOUSECONFIG_MERGETREE.fields_by_name['merge_selecting_sleep_ms']._options = None
  _CLICKHOUSECONFIG_MERGETREE.fields_by_name['merge_selecting_sleep_ms']._serialized_options = b'\372\3071\002>0'
  _CLICKHOUSECONFIG_MERGETREE.fields_by_name['merge_max_block_size']._options = None
  _CLICKHOUSECONFIG_MERGETREE.fields_by_name['merge_max_block_size']._serialized_options = b'\372\3071\002>0'
  _CLICKHOUSECONFIG_MERGETREE.fields_by_name['max_merge_selecting_sleep_ms']._options = None
  _CLICKHOUSECONFIG_MERGETREE.fields_by_name['max_merge_selecting_sleep_ms']._serialized_options = b'\372\3071\003>=0'
  _CLICKHOUSECONFIG_MERGETREE.fields_by_name['max_cleanup_delay_period']._options = None
  _CLICKHOUSECONFIG_MERGETREE.fields_by_name['max_cleanup_delay_period']._serialized_options = b'\372\3071\003>=0'
  _CLICKHOUSECONFIG_KAFKA.fields_by_name['max_poll_interval_ms']._options = None
  _CLICKHOUSECONFIG_KAFKA.fields_by_name['max_poll_interval_ms']._serialized_options = b'\372\3071\003>=0'
  _CLICKHOUSECONFIG_KAFKA.fields_by_name['session_timeout_ms']._options = None
  _CLICKHOUSECONFIG_KAFKA.fields_by_name['session_timeout_ms']._serialized_options = b'\372\3071\003>=0'
  _CLICKHOUSECONFIG_KAFKATOPIC.fields_by_name['name']._options = None
  _CLICKHOUSECONFIG_KAFKATOPIC.fields_by_name['name']._serialized_options = b'\350\3071\001'
  _CLICKHOUSECONFIG_KAFKATOPIC.fields_by_name['settings']._options = None
  _CLICKHOUSECONFIG_KAFKATOPIC.fields_by_name['settings']._serialized_options = b'\350\3071\001'
  _CLICKHOUSECONFIG_COMPRESSION.fields_by_name['min_part_size']._options = None
  _CLICKHOUSECONFIG_COMPRESSION.fields_by_name['min_part_size']._serialized_options = b'\372\3071\003>=1'
  _CLICKHOUSECONFIG_COMPRESSION.fields_by_name['level']._options = None
  _CLICKHOUSECONFIG_COMPRESSION.fields_by_name['level']._serialized_options = b'\372\3071\003>=0'
  _CLICKHOUSECONFIG_EXTERNALDICTIONARY_HTTPSOURCE_HEADER.fields_by_name['name']._options = None
  _CLICKHOUSECONFIG_EXTERNALDICTIONARY_HTTPSOURCE_HEADER.fields_by_name['name']._serialized_options = b'\350\3071\001'
  _CLICKHOUSECONFIG_EXTERNALDICTIONARY_HTTPSOURCE_HEADER.fields_by_name['value']._options = None
  _CLICKHOUSECONFIG_EXTERNALDICTIONARY_HTTPSOURCE_HEADER.fields_by_name['value']._serialized_options = b'\350\3071\001'
  _CLICKHOUSECONFIG_EXTERNALDICTIONARY_HTTPSOURCE.fields_by_name['url']._options = None
  _CLICKHOUSECONFIG_EXTERNALDICTIONARY_HTTPSOURCE.fields_by_name['url']._serialized_options = b'\350\3071\001'
  _CLICKHOUSECONFIG_EXTERNALDICTIONARY_HTTPSOURCE.fields_by_name['format']._options = None
  _CLICKHOUSECONFIG_EXTERNALDICTIONARY_HTTPSOURCE.fields_by_name['format']._serialized_options = b'\350\3071\001'
  _CLICKHOUSECONFIG_EXTERNALDICTIONARY_MYSQLSOURCE_REPLICA.fields_by_name['host']._options = None
  _CLICKHOUSECONFIG_EXTERNALDICTIONARY_MYSQLSOURCE_REPLICA.fields_by_name['host']._serialized_options = b'\350\3071\001\212\3101\005<=253'
  _CLICKHOUSECONFIG_EXTERNALDICTIONARY_MYSQLSOURCE_REPLICA.fields_by_name['priority']._options = None
  _CLICKHOUSECONFIG_EXTERNALDICTIONARY_MYSQLSOURCE_REPLICA.fields_by_name['priority']._serialized_options = b'\350\3071\001\372\3071\002>0'
  _CLICKHOUSECONFIG_EXTERNALDICTIONARY_MYSQLSOURCE_REPLICA.fields_by_name['port']._options = None
  _CLICKHOUSECONFIG_EXTERNALDICTIONARY_MYSQLSOURCE_REPLICA.fields_by_name['port']._serialized_options = b'\372\3071\0070-65535'
  _CLICKHOUSECONFIG_EXTERNALDICTIONARY_MYSQLSOURCE.fields_by_name['db']._options = None
  _CLICKHOUSECONFIG_EXTERNALDICTIONARY_MYSQLSOURCE.fields_by_name['db']._serialized_options = b'\350\3071\001'
  _CLICKHOUSECONFIG_EXTERNALDICTIONARY_MYSQLSOURCE.fields_by_name['table']._options = None
  _CLICKHOUSECONFIG_EXTERNALDICTIONARY_MYSQLSOURCE.fields_by_name['table']._serialized_options = b'\350\3071\001'
  _CLICKHOUSECONFIG_EXTERNALDICTIONARY_MYSQLSOURCE.fields_by_name['port']._options = None
  _CLICKHOUSECONFIG_EXTERNALDICTIONARY_MYSQLSOURCE.fields_by_name['port']._serialized_options = b'\372\3071\0070-65535'
  _CLICKHOUSECONFIG_EXTERNALDICTIONARY_MYSQLSOURCE.fields_by_name['replicas']._options = None
  _CLICKHOUSECONFIG_EXTERNALDICTIONARY_MYSQLSOURCE.fields_by_name['replicas']._serialized_options = b'\202\3101\002>0'
  _CLICKHOUSECONFIG_EXTERNALDICTIONARY_CLICKHOUSESOURCE.fields_by_name['db']._options = None
  _CLICKHOUSECONFIG_EXTERNALDICTIONARY_CLICKHOUSESOURCE.fields_by_name['db']._serialized_options = b'\350\3071\001'
  _CLICKHOUSECONFIG_EXTERNALDICTIONARY_CLICKHOUSESOURCE.fields_by_name['table']._options = None
  _CLICKHOUSECONFIG_EXTERNALDICTIONARY_CLICKHOUSESOURCE.fields_by_name['table']._serialized_options = b'\350\3071\001'
  _CLICKHOUSECONFIG_EXTERNALDICTIONARY_CLICKHOUSESOURCE.fields_by_name['host']._options = None
  _CLICKHOUSECONFIG_EXTERNALDICTIONARY_CLICKHOUSESOURCE.fields_by_name['host']._serialized_options = b'\212\3101\005<=253'
  _CLICKHOUSECONFIG_EXTERNALDICTIONARY_CLICKHOUSESOURCE.fields_by_name['port']._options = None
  _CLICKHOUSECONFIG_EXTERNALDICTIONARY_CLICKHOUSESOURCE.fields_by_name['port']._serialized_options = b'\372\3071\0070-65535'
  _CLICKHOUSECONFIG_EXTERNALDICTIONARY_CLICKHOUSESOURCE.fields_by_name['user']._options = None
  _CLICKHOUSECONFIG_EXTERNALDICTIONARY_CLICKHOUSESOURCE.fields_by_name['user']._serialized_options = b'\350\3071\001'
  _CLICKHOUSECONFIG_EXTERNALDICTIONARY_MONGODBSOURCE.fields_by_name['db']._options = None
  _CLICKHOUSECONFIG_EXTERNALDICTIONARY_MONGODBSOURCE.fields_by_name['db']._serialized_options = b'\350\3071\001'
  _CLICKHOUSECONFIG_EXTERNALDICTIONARY_MONGODBSOURCE.fields_by_name['collection']._options = None
  _CLICKHOUSECONFIG_EXTERNALDICTIONARY_MONGODBSOURCE.fields_by_name['collection']._serialized_options = b'\350\3071\001'
  _CLICKHOUSECONFIG_EXTERNALDICTIONARY_MONGODBSOURCE.fields_by_name['host']._options = None
  _CLICKHOUSECONFIG_EXTERNALDICTIONARY_MONGODBSOURCE.fields_by_name['host']._serialized_options = b'\212\3101\005<=253'
  _CLICKHOUSECONFIG_EXTERNALDICTIONARY_MONGODBSOURCE.fields_by_name['port']._options = None
  _CLICKHOUSECONFIG_EXTERNALDICTIONARY_MONGODBSOURCE.fields_by_name['port']._serialized_options = b'\372\3071\0070-65535'
  _CLICKHOUSECONFIG_EXTERNALDICTIONARY_MONGODBSOURCE.fields_by_name['user']._options = None
  _CLICKHOUSECONFIG_EXTERNALDICTIONARY_MONGODBSOURCE.fields_by_name['user']._serialized_options = b'\350\3071\001'
  _CLICKHOUSECONFIG_EXTERNALDICTIONARY_POSTGRESQLSOURCE.fields_by_name['db']._options = None
  _CLICKHOUSECONFIG_EXTERNALDICTIONARY_POSTGRESQLSOURCE.fields_by_name['db']._serialized_options = b'\350\3071\001'
  _CLICKHOUSECONFIG_EXTERNALDICTIONARY_POSTGRESQLSOURCE.fields_by_name['table']._options = None
  _CLICKHOUSECONFIG_EXTERNALDICTIONARY_POSTGRESQLSOURCE.fields_by_name['table']._serialized_options = b'\350\3071\001'
  _CLICKHOUSECONFIG_EXTERNALDICTIONARY_POSTGRESQLSOURCE.fields_by_name['hosts']._options = None
  _CLICKHOUSECONFIG_EXTERNALDICTIONARY_POSTGRESQLSOURCE.fields_by_name['hosts']._serialized_options = b'\202\3101\002>0'
  _CLICKHOUSECONFIG_EXTERNALDICTIONARY_POSTGRESQLSOURCE.fields_by_name['port']._options = None
  _CLICKHOUSECONFIG_EXTERNALDICTIONARY_POSTGRESQLSOURCE.fields_by_name['port']._serialized_options = b'\372\3071\0070-65535'
  _CLICKHOUSECONFIG_EXTERNALDICTIONARY_POSTGRESQLSOURCE.fields_by_name['user']._options = None
  _CLICKHOUSECONFIG_EXTERNALDICTIONARY_POSTGRESQLSOURCE.fields_by_name['user']._serialized_options = b'\350\3071\001'
  _CLICKHOUSECONFIG_EXTERNALDICTIONARY_STRUCTURE_ATTRIBUTE.fields_by_name['name']._options = None
  _CLICKHOUSECONFIG_EXTERNALDICTIONARY_STRUCTURE_ATTRIBUTE.fields_by_name['name']._serialized_options = b'\350\3071\001'
  _CLICKHOUSECONFIG_EXTERNALDICTIONARY_STRUCTURE_ATTRIBUTE.fields_by_name['type']._options = None
  _CLICKHOUSECONFIG_EXTERNALDICTIONARY_STRUCTURE_ATTRIBUTE.fields_by_name['type']._serialized_options = b'\350\3071\001'
  _CLICKHOUSECONFIG_EXTERNALDICTIONARY_STRUCTURE_ID.fields_by_name['name']._options = None
  _CLICKHOUSECONFIG_EXTERNALDICTIONARY_STRUCTURE_ID.fields_by_name['name']._serialized_options = b'\350\3071\001'
  _CLICKHOUSECONFIG_EXTERNALDICTIONARY_STRUCTURE_KEY.fields_by_name['attributes']._options = None
  _CLICKHOUSECONFIG_EXTERNALDICTIONARY_STRUCTURE_KEY.fields_by_name['attributes']._serialized_options = b'\202\3101\002>0'
  _CLICKHOUSECONFIG_EXTERNALDICTIONARY_STRUCTURE.fields_by_name['attributes']._options = None
  _CLICKHOUSECONFIG_EXTERNALDICTIONARY_STRUCTURE.fields_by_name['attributes']._serialized_options = b'\202\3101\002>0'
  _CLICKHOUSECONFIG_EXTERNALDICTIONARY_LAYOUT.fields_by_name['type']._options = None
  _CLICKHOUSECONFIG_EXTERNALDICTIONARY_LAYOUT.fields_by_name['type']._serialized_options = b'\350\3071\001'
  _CLICKHOUSECONFIG_EXTERNALDICTIONARY.oneofs_by_name['lifetime']._options = None
  _CLICKHOUSECONFIG_EXTERNALDICTIONARY.oneofs_by_name['lifetime']._serialized_options = b'\300\3011\001'
  _CLICKHOUSECONFIG_EXTERNALDICTIONARY.oneofs_by_name['source']._options = None
  _CLICKHOUSECONFIG_EXTERNALDICTIONARY.oneofs_by_name['source']._serialized_options = b'\300\3011\001'
  _CLICKHOUSECONFIG_EXTERNALDICTIONARY.fields_by_name['name']._options = None
  _CLICKHOUSECONFIG_EXTERNALDICTIONARY.fields_by_name['name']._serialized_options = b'\350\3071\001'
  _CLICKHOUSECONFIG_EXTERNALDICTIONARY.fields_by_name['structure']._options = None
  _CLICKHOUSECONFIG_EXTERNALDICTIONARY.fields_by_name['structure']._serialized_options = b'\350\3071\001'
  _CLICKHOUSECONFIG_EXTERNALDICTIONARY.fields_by_name['layout']._options = None
  _CLICKHOUSECONFIG_EXTERNALDICTIONARY.fields_by_name['layout']._serialized_options = b'\350\3071\001'
  _CLICKHOUSECONFIG_GRAPHITEROLLUP_PATTERN_RETENTION.fields_by_name['age']._options = None
  _CLICKHOUSECONFIG_GRAPHITEROLLUP_PATTERN_RETENTION.fields_by_name['age']._serialized_options = b'\372\3071\003>=0'
  _CLICKHOUSECONFIG_GRAPHITEROLLUP_PATTERN_RETENTION.fields_by_name['precision']._options = None
  _CLICKHOUSECONFIG_GRAPHITEROLLUP_PATTERN_RETENTION.fields_by_name['precision']._serialized_options = b'\372\3071\002>0'
  _CLICKHOUSECONFIG_GRAPHITEROLLUP_PATTERN.fields_by_name['function']._options = None
  _CLICKHOUSECONFIG_GRAPHITEROLLUP_PATTERN.fields_by_name['function']._serialized_options = b'\350\3071\001'
  _CLICKHOUSECONFIG_GRAPHITEROLLUP_PATTERN.fields_by_name['retention']._options = None
  _CLICKHOUSECONFIG_GRAPHITEROLLUP_PATTERN.fields_by_name['retention']._serialized_options = b'\202\3101\002>0'
  _CLICKHOUSECONFIG_GRAPHITEROLLUP.fields_by_name['name']._options = None
  _CLICKHOUSECONFIG_GRAPHITEROLLUP.fields_by_name['name']._serialized_options = b'\350\3071\001'
  _CLICKHOUSECONFIG_GRAPHITEROLLUP.fields_by_name['patterns']._options = None
  _CLICKHOUSECONFIG_GRAPHITEROLLUP.fields_by_name['patterns']._serialized_options = b'\202\3101\002>0'
  _CLICKHOUSECONFIG_QUERYMASKINGRULE.fields_by_name['regexp']._options = None
  _CLICKHOUSECONFIG_QUERYMASKINGRULE.fields_by_name['regexp']._serialized_options = b'\350\3071\001'
  _CLICKHOUSECONFIG_QUERYCACHE.fields_by_name['max_size_in_bytes']._options = None
  _CLICKHOUSECONFIG_QUERYCACHE.fields_by_name['max_size_in_bytes']._serialized_options = b'\372\3071\003>=0'
  _CLICKHOUSECONFIG_QUERYCACHE.fields_by_name['max_entries']._options = None
  _CLICKHOUSECONFIG_QUERYCACHE.fields_by_name['max_entries']._serialized_options = b'\372\3071\003>=0'
  _CLICKHOUSECONFIG_QUERYCACHE.fields_by_name['max_entry_size_in_bytes']._options = None
  _CLICKHOUSECONFIG_QUERYCACHE.fields_by_name['max_entry_size_in_bytes']._serialized_options = b'\372\3071\003>=0'
  _CLICKHOUSECONFIG_QUERYCACHE.fields_by_name['max_entry_size_in_rows']._options = None
  _CLICKHOUSECONFIG_QUERYCACHE.fields_by_name['max_entry_size_in_rows']._serialized_options = b'\372\3071\003>=0'
  _CLICKHOUSECONFIG.fields_by_name['max_connections']._options = None
  _CLICKHOUSECONFIG.fields_by_name['max_connections']._serialized_options = b'\372\3071\004>=10'
  _CLICKHOUSECONFIG.fields_by_name['max_concurrent_queries']._options = None
  _CLICKHOUSECONFIG.fields_by_name['max_concurrent_queries']._serialized_options = b'\372\3071\004>=10'
  _CLICKHOUSECONFIG.fields_by_name['mark_cache_size']._options = None
  _CLICKHOUSECONFIG.fields_by_name['mark_cache_size']._serialized_options = b'\372\3071\002>0'
  _CLICKHOUSECONFIG.fields_by_name['builtin_dictionaries_reload_interval']._options = None
  _CLICKHOUSECONFIG.fields_by_name['builtin_dictionaries_reload_interval']._serialized_options = b'\030\001'
  _CLICKHOUSECONFIG.fields_by_name['opentelemetry_span_log_retention_size']._options = None
  _CLICKHOUSECONFIG.fields_by_name['opentelemetry_span_log_retention_size']._serialized_options = b'\372\3071\003>=0'
  _CLICKHOUSECONFIG.fields_by_name['opentelemetry_span_log_retention_time']._options = None
  _CLICKHOUSECONFIG.fields_by_name['opentelemetry_span_log_retention_time']._serialized_options = b'\372\3071\003>=0'
  _CLICKHOUSECONFIG.fields_by_name['query_views_log_retention_size']._options = None
  _CLICKHOUSECONFIG.fields_by_name['query_views_log_retention_size']._serialized_options = b'\372\3071\003>=0'
  _CLICKHOUSECONFIG.fields_by_name['query_views_log_retention_time']._options = None
  _CLICKHOUSECONFIG.fields_by_name['query_views_log_retention_time']._serialized_options = b'\372\3071\003>=0'
  _CLICKHOUSECONFIG.fields_by_name['asynchronous_metric_log_retention_size']._options = None
  _CLICKHOUSECONFIG.fields_by_name['asynchronous_metric_log_retention_size']._serialized_options = b'\372\3071\003>=0'
  _CLICKHOUSECONFIG.fields_by_name['asynchronous_metric_log_retention_time']._options = None
  _CLICKHOUSECONFIG.fields_by_name['asynchronous_metric_log_retention_time']._serialized_options = b'\372\3071\003>=0'
  _CLICKHOUSECONFIG.fields_by_name['session_log_retention_size']._options = None
  _CLICKHOUSECONFIG.fields_by_name['session_log_retention_size']._serialized_options = b'\372\3071\003>=0'
  _CLICKHOUSECONFIG.fields_by_name['session_log_retention_time']._options = None
  _CLICKHOUSECONFIG.fields_by_name['session_log_retention_time']._serialized_options = b'\372\3071\003>=0'
  _CLICKHOUSECONFIG.fields_by_name['zookeeper_log_retention_size']._options = None
  _CLICKHOUSECONFIG.fields_by_name['zookeeper_log_retention_size']._serialized_options = b'\372\3071\003>=0'
  _CLICKHOUSECONFIG.fields_by_name['zookeeper_log_retention_time']._options = None
  _CLICKHOUSECONFIG.fields_by_name['zookeeper_log_retention_time']._serialized_options = b'\372\3071\003>=0'
  _CLICKHOUSECONFIG.fields_by_name['asynchronous_insert_log_retention_size']._options = None
  _CLICKHOUSECONFIG.fields_by_name['asynchronous_insert_log_retention_size']._serialized_options = b'\372\3071\003>=0'
  _CLICKHOUSECONFIG.fields_by_name['asynchronous_insert_log_retention_time']._options = None
  _CLICKHOUSECONFIG.fields_by_name['asynchronous_insert_log_retention_time']._serialized_options = b'\372\3071\003>=0'
  _CLICKHOUSECONFIG.fields_by_name['background_pool_size']._options = None
  _CLICKHOUSECONFIG.fields_by_name['background_pool_size']._serialized_options = b'\372\3071\002>0'
  _CLICKHOUSECONFIG.fields_by_name['background_merges_mutations_concurrency_ratio']._options = None
  _CLICKHOUSECONFIG.fields_by_name['background_merges_mutations_concurrency_ratio']._serialized_options = b'\372\3071\002>0'
  _CLICKHOUSECONFIG.fields_by_name['background_schedule_pool_size']._options = None
  _CLICKHOUSECONFIG.fields_by_name['background_schedule_pool_size']._serialized_options = b'\372\3071\002>0'
  _CLICKHOUSECONFIG.fields_by_name['background_fetches_pool_size']._options = None
  _CLICKHOUSECONFIG.fields_by_name['background_fetches_pool_size']._serialized_options = b'\372\3071\002>0'
  _CLICKHOUSECONFIG.fields_by_name['background_move_pool_size']._options = None
  _CLICKHOUSECONFIG.fields_by_name['background_move_pool_size']._serialized_options = b'\372\3071\002>0'
  _CLICKHOUSECONFIG.fields_by_name['background_distributed_schedule_pool_size']._options = None
  _CLICKHOUSECONFIG.fields_by_name['background_distributed_schedule_pool_size']._serialized_options = b'\372\3071\002>0'
  _CLICKHOUSECONFIG.fields_by_name['background_buffer_flush_schedule_pool_size']._options = None
  _CLICKHOUSECONFIG.fields_by_name['background_buffer_flush_schedule_pool_size']._serialized_options = b'\372\3071\002>0'
  _CLICKHOUSECONFIG.fields_by_name['background_message_broker_schedule_pool_size']._options = None
  _CLICKHOUSECONFIG.fields_by_name['background_message_broker_schedule_pool_size']._serialized_options = b'\372\3071\002>0'
  _CLICKHOUSECONFIG.fields_by_name['background_common_pool_size']._options = None
  _CLICKHOUSECONFIG.fields_by_name['background_common_pool_size']._serialized_options = b'\372\3071\002>0'
  _CLICKHOUSECONFIG.fields_by_name['query_masking_rules']._options = None
  _CLICKHOUSECONFIG.fields_by_name['query_masking_rules']._serialized_options = b'\202\3101\002>0'
  _CLICKHOUSECONFIGSET.fields_by_name['effective_config']._options = None
  _CLICKHOUSECONFIGSET.fields_by_name['effective_config']._serialized_options = b'\350\3071\001'
  _globals['_CLICKHOUSECONFIG']._serialized_start=161
  _globals['_CLICKHOUSECONFIG']._serialized_end=13938
  _globals['_CLICKHOUSECONFIG_MERGETREE']._serialized_start=5126
  _globals['_CLICKHOUSECONFIG_MERGETREE']._serialized_end=7130
  _globals['_CLICKHOUSECONFIG_KAFKA']._serialized_start=7133
  _globals['_CLICKHOUSECONFIG_KAFKA']._serialized_end=8829
  _globals['_CLICKHOUSECONFIG_KAFKA_SECURITYPROTOCOL']._serialized_start=7794
  _globals['_CLICKHOUSECONFIG_KAFKA_SECURITYPROTOCOL']._serialized_end=7977
  _globals['_CLICKHOUSECONFIG_KAFKA_SASLMECHANISM']._serialized_start=7980
  _globals['_CLICKHOUSECONFIG_KAFKA_SASLMECHANISM']._serialized_end=8148
  _globals['_CLICKHOUSECONFIG_KAFKA_DEBUG']._serialized_start=8151
  _globals['_CLICKHOUSECONFIG_KAFKA_DEBUG']._serialized_end=8560
  _globals['_CLICKHOUSECONFIG_KAFKA_AUTOOFFSETRESET']._serialized_start=8563
  _globals['_CLICKHOUSECONFIG_KAFKA_AUTOOFFSETRESET']._serialized_end=8829
  _globals['_CLICKHOUSECONFIG_KAFKATOPIC']._serialized_start=8831
  _globals['_CLICKHOUSECONFIG_KAFKATOPIC']._serialized_end=8950
  _globals['_CLICKHOUSECONFIG_RABBITMQ']._serialized_start=8952
  _globals['_CLICKHOUSECONFIG_RABBITMQ']._serialized_end=9013
  _globals['_CLICKHOUSECONFIG_COMPRESSION']._serialized_start=9016
  _globals['_CLICKHOUSECONFIG_COMPRESSION']._serialized_end=9288
  _globals['_CLICKHOUSECONFIG_COMPRESSION_METHOD']._serialized_start=9237
  _globals['_CLICKHOUSECONFIG_COMPRESSION_METHOD']._serialized_end=9288
  _globals['_CLICKHOUSECONFIG_EXTERNALDICTIONARY']._serialized_start=9291
  _globals['_CLICKHOUSECONFIG_EXTERNALDICTIONARY']._serialized_end=12999
  _globals['_CLICKHOUSECONFIG_EXTERNALDICTIONARY_HTTPSOURCE']._serialized_start=10266
  _globals['_CLICKHOUSECONFIG_EXTERNALDICTIONARY_HTTPSOURCE']._serialized_end=10481
  _globals['_CLICKHOUSECONFIG_EXTERNALDICTIONARY_HTTPSOURCE_HEADER']._serialized_start=10432
  _globals['_CLICKHOUSECONFIG_EXTERNALDICTIONARY_HTTPSOURCE_HEADER']._serialized_end=10481
  _globals['_CLICKHOUSECONFIG_EXTERNALDICTIONARY_MYSQLSOURCE']._serialized_start=10484
  _globals['_CLICKHOUSECONFIG_EXTERNALDICTIONARY_MYSQLSOURCE']._serialized_end=10995
  _globals['_CLICKHOUSECONFIG_EXTERNALDICTIONARY_MYSQLSOURCE_REPLICA']._serialized_start=10868
  _globals['_CLICKHOUSECONFIG_EXTERNALDICTIONARY_MYSQLSOURCE_REPLICA']._serialized_end=10995
  _globals['_CLICKHOUSECONFIG_EXTERNALDICTIONARY_CLICKHOUSESOURCE']._serialized_start=10998
  _globals['_CLICKHOUSECONFIG_EXTERNALDICTIONARY_CLICKHOUSESOURCE']._serialized_end=11204
  _globals['_CLICKHOUSECONFIG_EXTERNALDICTIONARY_MONGODBSOURCE']._serialized_start=11207
  _globals['_CLICKHOUSECONFIG_EXTERNALDICTIONARY_MONGODBSOURCE']._serialized_end=11373
  _globals['_CLICKHOUSECONFIG_EXTERNALDICTIONARY_POSTGRESQLSOURCE']._serialized_start=11376
  _globals['_CLICKHOUSECONFIG_EXTERNALDICTIONARY_POSTGRESQLSOURCE']._serialized_end=11771
  _globals['_CLICKHOUSECONFIG_EXTERNALDICTIONARY_POSTGRESQLSOURCE_SSLMODE']._serialized_start=11668
  _globals['_CLICKHOUSECONFIG_EXTERNALDICTIONARY_POSTGRESQLSOURCE_SSLMODE']._serialized_end=11771
  _globals['_CLICKHOUSECONFIG_EXTERNALDICTIONARY_STRUCTURE']._serialized_start=11774
  _globals['_CLICKHOUSECONFIG_EXTERNALDICTIONARY_STRUCTURE']._serialized_end=12636
  _globals['_CLICKHOUSECONFIG_EXTERNALDICTIONARY_STRUCTURE_ATTRIBUTE']._serialized_start=12346
  _globals['_CLICKHOUSECONFIG_EXTERNALDICTIONARY_STRUCTURE_ATTRIBUTE']._serialized_end=12478
  _globals['_CLICKHOUSECONFIG_EXTERNALDICTIONARY_STRUCTURE_ID']._serialized_start=12480
  _globals['_CLICKHOUSECONFIG_EXTERNALDICTIONARY_STRUCTURE_ID']._serialized_end=12504
  _globals['_CLICKHOUSECONFIG_EXTERNALDICTIONARY_STRUCTURE_KEY']._serialized_start=12507
  _globals['_CLICKHOUSECONFIG_EXTERNALDICTIONARY_STRUCTURE_KEY']._serialized_end=12636
  _globals['_CLICKHOUSECONFIG_EXTERNALDICTIONARY_LAYOUT']._serialized_start=12639
  _globals['_CLICKHOUSECONFIG_EXTERNALDICTIONARY_LAYOUT']._serialized_end=12930
  _globals['_CLICKHOUSECONFIG_EXTERNALDICTIONARY_LAYOUT_TYPE']._serialized_start=12804
  _globals['_CLICKHOUSECONFIG_EXTERNALDICTIONARY_LAYOUT_TYPE']._serialized_end=12930
  _globals['_CLICKHOUSECONFIG_EXTERNALDICTIONARY_RANGE']._serialized_start=12932
  _globals['_CLICKHOUSECONFIG_EXTERNALDICTIONARY_RANGE']._serialized_end=12965
  _globals['_CLICKHOUSECONFIG_GRAPHITEROLLUP']._serialized_start=13002
  _globals['_CLICKHOUSECONFIG_GRAPHITEROLLUP']._serialized_end=13483
  _globals['_CLICKHOUSECONFIG_GRAPHITEROLLUP_PATTERN']._serialized_start=13255
  _globals['_CLICKHOUSECONFIG_GRAPHITEROLLUP_PATTERN']._serialized_end=13483
  _globals['_CLICKHOUSECONFIG_GRAPHITEROLLUP_PATTERN_RETENTION']._serialized_start=13423
  _globals['_CLICKHOUSECONFIG_GRAPHITEROLLUP_PATTERN_RETENTION']._serialized_end=13483
  _globals['_CLICKHOUSECONFIG_QUERYMASKINGRULE']._serialized_start=13485
  _globals['_CLICKHOUSECONFIG_QUERYMASKINGRULE']._serialized_end=13556
  _globals['_CLICKHOUSECONFIG_QUERYCACHE']._serialized_start=13559
  _globals['_CLICKHOUSECONFIG_QUERYCACHE']._serialized_end=13836
  _globals['_CLICKHOUSECONFIG_LOGLEVEL']._serialized_start=13838
  _globals['_CLICKHOUSECONFIG_LOGLEVEL']._serialized_end=13938
  _globals['_CLICKHOUSECONFIGSET']._serialized_start=13941
  _globals['_CLICKHOUSECONFIGSET']._serialized_end=14210
# @@protoc_insertion_point(module_scope)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import google.protobuf.timestamp_pb2
import typing

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class Channel(google.protobuf.message.Message):
    """Root entity for content separation."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing.final
    class LabelsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing.Literal["key", b"key", "value", b"value"]) -> None: ...

    ID_FIELD_NUMBER: builtins.int
    ORGANIZATION_ID_FIELD_NUMBER: builtins.int
    TITLE_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    CREATED_AT_FIELD_NUMBER: builtins.int
    UPDATED_AT_FIELD_NUMBER: builtins.int
    LABELS_FIELD_NUMBER: builtins.int
    id: builtins.str
    """ID of the channel."""
    organization_id: builtins.str
    """ID of the organization where channel should be created."""
    title: builtins.str
    """Channel title."""
    description: builtins.str
    """Channel description."""
    @property
    def created_at(self) -> google.protobuf.timestamp_pb2.Timestamp:
        """Time when channel was created."""

    @property
    def updated_at(self) -> google.protobuf.timestamp_pb2.Timestamp:
        """Time of last channel update."""

    @property
    def labels(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]:
        """Custom labels as `` key:value `` pairs. Maximum 64 per resource."""

    def __init__(
        self,
        *,
        id: builtins.str = ...,
        organization_id: builtins.str = ...,
        title: builtins.str = ...,
        description: builtins.str = ...,
        created_at: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        updated_at: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        labels: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["created_at", b"created_at", "updated_at", b"updated_at"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["created_at", b"created_at", "description", b"description", "id", b"id", "labels", b"labels", "organization_id", b"organization_id", "title", b"title", "updated_at", b"updated_at"]) -> None: ...

global___Channel = Channel



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import google.protobuf.descriptor
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import google.protobuf.struct_pb2
import google.protobuf.timestamp_pb2
import sys
import typing
import yandex.cloud.logging.v1.log_resource_pb2

if sys.version_info >= (3, 10):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class LogEntry(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    UID_FIELD_NUMBER: builtins.int
    RESOURCE_FIELD_NUMBER: builtins.int
    TIMESTAMP_FIELD_NUMBER: builtins.int
    INGESTED_AT_FIELD_NUMBER: builtins.int
    SAVED_AT_FIELD_NUMBER: builtins.int
    LEVEL_FIELD_NUMBER: builtins.int
    MESSAGE_FIELD_NUMBER: builtins.int
    JSON_PAYLOAD_FIELD_NUMBER: builtins.int
    STREAM_NAME_FIELD_NUMBER: builtins.int
    uid: builtins.str
    """Unique entry ID.

    Useful for logs deduplication.
    """
    level: global___LogLevel.Level.ValueType
    """Entry severity.

    See [LogLevel.Level] for details.
    """
    message: builtins.str
    """Entry text message."""
    stream_name: builtins.str
    """Entry stream name."""
    @property
    def resource(self) -> yandex.cloud.logging.v1.log_resource_pb2.LogEntryResource:
        """Entry resource specification.

        May contain information about source service and resource ID.
        Also may be provided by the user.
        """

    @property
    def timestamp(self) -> google.protobuf.timestamp_pb2.Timestamp:
        """Timestamp of the entry."""

    @property
    def ingested_at(self) -> google.protobuf.timestamp_pb2.Timestamp:
        """Entry ingestion time observed by [LogIngestionService]."""

    @property
    def saved_at(self) -> google.protobuf.timestamp_pb2.Timestamp:
        """Entry save time.

        Entry is ready to be read since this moment.
        """

    @property
    def json_payload(self) -> google.protobuf.struct_pb2.Struct:
        """Entry annotation."""

    def __init__(
        self,
        *,
        uid: builtins.str = ...,
        resource: yandex.cloud.logging.v1.log_resource_pb2.LogEntryResource | None = ...,
        timestamp: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        ingested_at: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        saved_at: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        level: global___LogLevel.Level.ValueType = ...,
        message: builtins.str = ...,
        json_payload: google.protobuf.struct_pb2.Struct | None = ...,
        stream_name: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["ingested_at", b"ingested_at", "json_payload", b"json_payload", "resource", b"resource", "saved_at", b"saved_at", "timestamp", b"timestamp"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["ingested_at", b"ingested_at", "json_payload", b"json_payload", "level", b"level", "message", b"message", "resource", b"resource", "saved_at", b"saved_at", "stream_name", b"stream_name", "timestamp", b"timestamp", "uid", b"uid"]) -> None: ...

global___LogEntry = LogEntry

@typing.final
class IncomingLogEntry(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TIMESTAMP_FIELD_NUMBER: builtins.int
    LEVEL_FIELD_NUMBER: builtins.int
    MESSAGE_FIELD_NUMBER: builtins.int
    JSON_PAYLOAD_FIELD_NUMBER: builtins.int
    STREAM_NAME_FIELD_NUMBER: builtins.int
    level: global___LogLevel.Level.ValueType
    """Entry severity.

    See [LogLevel.Level] for details.
    """
    message: builtins.str
    """Entry text message."""
    stream_name: builtins.str
    """Entry stream name."""
    @property
    def timestamp(self) -> google.protobuf.timestamp_pb2.Timestamp:
        """Timestamp of the entry."""

    @property
    def json_payload(self) -> google.protobuf.struct_pb2.Struct:
        """Entry annotation."""

    def __init__(
        self,
        *,
        timestamp: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        level: global___LogLevel.Level.ValueType = ...,
        message: builtins.str = ...,
        json_payload: google.protobuf.struct_pb2.Struct | None = ...,
        stream_name: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["json_payload", b"json_payload", "timestamp", b"timestamp"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["json_payload", b"json_payload", "level", b"level", "message", b"message", "stream_name", b"stream_name", "timestamp", b"timestamp"]) -> None: ...

global___IncomingLogEntry = IncomingLogEntry

@typing.final
class LogEntryDefaults(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    LEVEL_FIELD_NUMBER: builtins.int
    JSON_PAYLOAD_FIELD_NUMBER: builtins.int
    STREAM_NAME_FIELD_NUMBER: builtins.int
    level: global___LogLevel.Level.ValueType
    """Default entry severity.
    Will be applied if entry level is unspecified.

    See [LogLevel.Level] for details.
    """
    stream_name: builtins.str
    """Entry stream name."""
    @property
    def json_payload(self) -> google.protobuf.struct_pb2.Struct:
        """Default entry annotation.
        Will be merged with entry annotation.
        Any conflict will be resolved in favor of entry own annotation.
        """

    def __init__(
        self,
        *,
        level: global___LogLevel.Level.ValueType = ...,
        json_payload: google.protobuf.struct_pb2.Struct | None = ...,
        stream_name: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["json_payload", b"json_payload"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["json_payload", b"json_payload", "level", b"level", "stream_name", b"stream_name"]) -> None: ...

global___LogEntryDefaults = LogEntryDefaults

@typing.final
class Destination(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    LOG_GROUP_ID_FIELD_NUMBER: builtins.int
    FOLDER_ID_FIELD_NUMBER: builtins.int
    log_group_id: builtins.str
    """Entry should be written to log group resolved by ID."""
    folder_id: builtins.str
    """Entry should be written to default log group for the folder."""
    def __init__(
        self,
        *,
        log_group_id: builtins.str = ...,
        folder_id: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["destination", b"destination", "folder_id", b"folder_id", "log_group_id", b"log_group_id"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["destination", b"destination", "folder_id", b"folder_id", "log_group_id", b"log_group_id"]) -> None: ...
    def WhichOneof(self, oneof_group: typing.Literal["destination", b"destination"]) -> typing.Literal["log_group_id", "folder_id"] | None: ...

global___Destination = Destination

@typing.final
class LogLevel(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    class _Level:
        ValueType = typing.NewType("ValueType", builtins.int)
        V: typing_extensions.TypeAlias = ValueType

    class _LevelEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[LogLevel._Level.ValueType], builtins.type):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
        LEVEL_UNSPECIFIED: LogLevel._Level.ValueType  # 0
        """Default log level.

        Equivalent to not specifying log level at all.
        """
        TRACE: LogLevel._Level.ValueType  # 1
        """Trace log level.

        Possible use case: verbose logging of some business logic.
        """
        DEBUG: LogLevel._Level.ValueType  # 2
        """Debug log level.

        Possible use case: debugging special cases in application logic.
        """
        INFO: LogLevel._Level.ValueType  # 3
        """Info log level.

        Mostly used for information messages.
        """
        WARN: LogLevel._Level.ValueType  # 4
        """Warn log level.

        May be used to alert about significant events.
        """
        ERROR: LogLevel._Level.ValueType  # 5
        """Error log level.

        May be used to alert about errors in infrastructure, logic, etc.
        """
        FATAL: LogLevel._Level.ValueType  # 6
        """Fatal log level.

        May be used to alert about unrecoverable failures and events.
        """

    class Level(_Level, metaclass=_LevelEnumTypeWrapper):
        """Possible log levels for entries."""

    LEVEL_UNSPECIFIED: LogLevel.Level.ValueType  # 0
    """Default log level.

    Equivalent to not specifying log level at all.
    """
    TRACE: LogLevel.Level.ValueType  # 1
    """Trace log level.

    Possible use case: verbose logging of some business logic.
    """
    DEBUG: LogLevel.Level.ValueType  # 2
    """Debug log level.

    Possible use case: debugging special cases in application logic.
    """
    INFO: LogLevel.Level.ValueType  # 3
    """Info log level.

    Mostly used for information messages.
    """
    WARN: LogLevel.Level.ValueType  # 4
    """Warn log level.

    May be used to alert about significant events.
    """
    ERROR: LogLevel.Level.ValueType  # 5
    """Error log level.

    May be used to alert about errors in infrastructure, logic, etc.
    """
    FATAL: LogLevel.Level.ValueType  # 6
    """Fatal log level.

    May be used to alert about unrecoverable failures and events.
    """

    LEVEL_FIELD_NUMBER: builtins.int
    level: global___LogLevel.Level.ValueType
    """Entry level.

    See [Level] for possible values.
    """
    def __init__(
        self,
        *,
        level: global___LogLevel.Level.ValueType = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["level", b"level"]) -> None: ...

global___LogLevel = LogLevel



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.field_mask_pb2
import google.protobuf.internal.containers
import google.protobuf.message
import typing
import yandex.cloud.iam.v1.workload.oidc.federation_pb2

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class GetFederationRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    FEDERATION_ID_FIELD_NUMBER: builtins.int
    federation_id: builtins.str
    """ID of the OIDC workload identity federation to return.
    To get the OIDC workload identity federation ID, make a [FederationService.List] request.
    """
    def __init__(
        self,
        *,
        federation_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["federation_id", b"federation_id"]) -> None: ...

global___GetFederationRequest = GetFederationRequest

@typing.final
class ListFederationsRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    FOLDER_ID_FIELD_NUMBER: builtins.int
    PAGE_SIZE_FIELD_NUMBER: builtins.int
    PAGE_TOKEN_FIELD_NUMBER: builtins.int
    folder_id: builtins.str
    """ID of the folder to list OIDC workload identity federations in.
    To get the folder ID, make a [yandex.cloud.resourcemanager.v1.FolderService.List] request.
    """
    page_size: builtins.int
    """The maximum number of results per page to return. If the number of available
    results is larger than [page_size],
    the service returns a [ListFederationsResponse.next_page_token]
    that can be used to get the next page of results in subsequent list requests.
    Default value: 100
    """
    page_token: builtins.str
    """Page token. To get the next page of results, set [page_token]
    to the [ListFederationsResponse.next_page_token]
    returned by a previous list request.
    """
    def __init__(
        self,
        *,
        folder_id: builtins.str = ...,
        page_size: builtins.int = ...,
        page_token: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["folder_id", b"folder_id", "page_size", b"page_size", "page_token", b"page_token"]) -> None: ...

global___ListFederationsRequest = ListFederationsRequest

@typing.final
class ListFederationsResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    FEDERATIONS_FIELD_NUMBER: builtins.int
    NEXT_PAGE_TOKEN_FIELD_NUMBER: builtins.int
    next_page_token: builtins.str
    """This token allows you to get the next page of results for list requests. If the number of results
    is larger than [ListFederationsRequest.page_size], use
    the [next_page_token] as the value
    for the [ListFederationsRequest.page_token] query parameter
    in the next list request. Each subsequent list request will have its own
    [next_page_token] to continue paging through the results.
    """
    @property
    def federations(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[yandex.cloud.iam.v1.workload.oidc.federation_pb2.Federation]:
        """List of OIDC workload identity federations."""

    def __init__(
        self,
        *,
        federations: collections.abc.Iterable[yandex.cloud.iam.v1.workload.oidc.federation_pb2.Federation] | None = ...,
        next_page_token: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["federations", b"federations", "next_page_token", b"next_page_token"]) -> None: ...

global___ListFederationsResponse = ListFederationsResponse

@typing.final
class CreateFederationRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing.final
    class LabelsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing.Literal["key", b"key", "value", b"value"]) -> None: ...

    FOLDER_ID_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    DISABLED_FIELD_NUMBER: builtins.int
    AUDIENCES_FIELD_NUMBER: builtins.int
    ISSUER_FIELD_NUMBER: builtins.int
    JWKS_URL_FIELD_NUMBER: builtins.int
    LABELS_FIELD_NUMBER: builtins.int
    folder_id: builtins.str
    """ID of the folder to create an OIDC workload identity federation in.
    To get the folder ID, make a [yandex.cloud.resourcemanager.v1.FolderService.List] request.
    """
    name: builtins.str
    """Name of the OIDC workload identity federation.
    The name must be unique within the folder.
    """
    description: builtins.str
    """Description of the OIDC workload identity federation."""
    disabled: builtins.bool
    """True - the OIDC workload identity federation is disabled and cannot be used for authentication.
    False - the OIDC workload identity federation is enabled and can be used for authentication.
    """
    issuer: builtins.str
    """URL of the external IdP server to be used for authentication."""
    jwks_url: builtins.str
    """URL reference to trusted keys in format of JSON Web Key Set."""
    @property
    def audiences(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]:
        """List of trusted values for aud claim."""

    @property
    def labels(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]:
        """Resource labels as `` key:value `` pairs"""

    def __init__(
        self,
        *,
        folder_id: builtins.str = ...,
        name: builtins.str = ...,
        description: builtins.str = ...,
        disabled: builtins.bool = ...,
        audiences: collections.abc.Iterable[builtins.str] | None = ...,
        issuer: builtins.str = ...,
        jwks_url: builtins.str = ...,
        labels: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["audiences", b"audiences", "description", b"description", "disabled", b"disabled", "folder_id", b"folder_id", "issuer", b"issuer", "jwks_url", b"jwks_url", "labels", b"labels", "name", b"name"]) -> None: ...

global___CreateFederationRequest = CreateFederationRequest

@typing.final
class CreateFederationMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    FEDERATION_ID_FIELD_NUMBER: builtins.int
    federation_id: builtins.str
    """ID of the OIDC workload identity federation that is being created."""
    def __init__(
        self,
        *,
        federation_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["federation_id", b"federation_id"]) -> None: ...

global___CreateFederationMetadata = CreateFederationMetadata

@typing.final
class UpdateFederationRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing.final
    class LabelsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing.Literal["key", b"key", "value", b"value"]) -> None: ...

    FEDERATION_ID_FIELD_NUMBER: builtins.int
    UPDATE_MASK_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    DISABLED_FIELD_NUMBER: builtins.int
    AUDIENCES_FIELD_NUMBER: builtins.int
    JWKS_URL_FIELD_NUMBER: builtins.int
    LABELS_FIELD_NUMBER: builtins.int
    federation_id: builtins.str
    """ID of the OIDC workload identity federation to update.
    To get the OIDC workload identity federation ID, make a [FederationService.List] request.
    """
    name: builtins.str
    """Name of the OIDC workload identity federation.
    The name must be unique within the folder.
    """
    description: builtins.str
    """Description of the OIDC workload identity federation."""
    disabled: builtins.bool
    """True - the OIDC workload identity federation is disabled and cannot be used for authentication.
    False - the OIDC workload identity federation is enabled and can be used for authentication.
    """
    jwks_url: builtins.str
    """URL reference to trusted keys in format of JSON Web Key Set."""
    @property
    def update_mask(self) -> google.protobuf.field_mask_pb2.FieldMask:
        """Field mask that specifies which fields of the OIDC workload identity federation are going to be updated."""

    @property
    def audiences(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]:
        """List of trusted values for aud claim."""

    @property
    def labels(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]:
        """Resource labels as `` key:value `` pairs"""

    def __init__(
        self,
        *,
        federation_id: builtins.str = ...,
        update_mask: google.protobuf.field_mask_pb2.FieldMask | None = ...,
        name: builtins.str = ...,
        description: builtins.str = ...,
        disabled: builtins.bool = ...,
        audiences: collections.abc.Iterable[builtins.str] | None = ...,
        jwks_url: builtins.str = ...,
        labels: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["update_mask", b"update_mask"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["audiences", b"audiences", "description", b"description", "disabled", b"disabled", "federation_id", b"federation_id", "jwks_url", b"jwks_url", "labels", b"labels", "name", b"name", "update_mask", b"update_mask"]) -> None: ...

global___UpdateFederationRequest = UpdateFederationRequest

@typing.final
class UpdateFederationMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    FEDERATION_ID_FIELD_NUMBER: builtins.int
    federation_id: builtins.str
    """ID of the OIDC workload identity federation that is being updated."""
    def __init__(
        self,
        *,
        federation_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["federation_id", b"federation_id"]) -> None: ...

global___UpdateFederationMetadata = UpdateFederationMetadata

@typing.final
class DeleteFederationRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    FEDERATION_ID_FIELD_NUMBER: builtins.int
    federation_id: builtins.str
    """ID of the OIDC workload identity federation to delete.
    To get the OIDC workload identity federation ID, make a [FederationService.List] request.
    """
    def __init__(
        self,
        *,
        federation_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["federation_id", b"federation_id"]) -> None: ...

global___DeleteFederationRequest = DeleteFederationRequest

@typing.final
class DeleteFederationMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    FEDERATION_ID_FIELD_NUMBER: builtins.int
    federation_id: builtins.str
    """ID of the OIDC workload identity federation that is being deleted."""
    def __init__(
        self,
        *,
        federation_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["federation_id", b"federation_id"]) -> None: ...

global___DeleteFederationMetadata = DeleteFederationMetadata



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: yandex/cloud/lockbox/v1/payload_service.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from yandex.cloud.lockbox.v1 import payload_pb2 as yandex_dot_cloud_dot_lockbox_dot_v1_dot_payload__pb2
from yandex.cloud import validation_pb2 as yandex_dot_cloud_dot_validation__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n-yandex/cloud/lockbox/v1/payload_service.proto\x12\x17yandex.cloud.lockbox.v1\x1a\x1cgoogle/api/annotations.proto\x1a%yandex/cloud/lockbox/v1/payload.proto\x1a\x1dyandex/cloud/validation.proto\"R\n\x11GetPayloadRequest\x12\x1f\n\tsecret_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x1c\n\nversion_id\x18\x02 \x01(\tB\x08\x8a\xc8\x31\x04<=502\x97\x01\n\x0ePayloadService\x12\x84\x01\n\x03Get\x12*.yandex.cloud.lockbox.v1.GetPayloadRequest\x1a .yandex.cloud.lockbox.v1.Payload\"/\x82\xd3\xe4\x93\x02)\x12\'/lockbox/v1/secrets/{secret_id}/payloadBb\n\x1byandex.cloud.api.lockbox.v1ZCgithub.com/yandex-cloud/go-genproto/yandex/cloud/lockbox/v1;lockboxb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.lockbox.v1.payload_service_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\033yandex.cloud.api.lockbox.v1ZCgithub.com/yandex-cloud/go-genproto/yandex/cloud/lockbox/v1;lockbox'
  _GETPAYLOADREQUEST.fields_by_name['secret_id']._options = None
  _GETPAYLOADREQUEST.fields_by_name['secret_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _GETPAYLOADREQUEST.fields_by_name['version_id']._options = None
  _GETPAYLOADREQUEST.fields_by_name['version_id']._serialized_options = b'\212\3101\004<=50'
  _PAYLOADSERVICE.methods_by_name['Get']._options = None
  _PAYLOADSERVICE.methods_by_name['Get']._serialized_options = b'\202\323\344\223\002)\022\'/lockbox/v1/secrets/{secret_id}/payload'
  _globals['_GETPAYLOADREQUEST']._serialized_start=174
  _globals['_GETPAYLOADREQUEST']._serialized_end=256
  _globals['_PAYLOADSERVICE']._serialized_start=259
  _globals['_PAYLOADSERVICE']._serialized_end=410
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: yandex/cloud/datatransfer/v1/endpoint/postgres.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from yandex.cloud.datatransfer.v1.endpoint import common_pb2 as yandex_dot_cloud_dot_datatransfer_dot_v1_dot_endpoint_dot_common__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n4yandex/cloud/datatransfer/v1/endpoint/postgres.proto\x12%yandex.cloud.datatransfer.v1.endpoint\x1a\x32yandex/cloud/datatransfer/v1/endpoint/common.proto\"\xaa\x0b\n\x1ePostgresObjectTransferSettings\x12L\n\x08sequence\x18\x01 \x01(\x0e\x32:.yandex.cloud.datatransfer.v1.endpoint.ObjectTransferStage\x12U\n\x11sequence_owned_by\x18\x02 \x01(\x0e\x32:.yandex.cloud.datatransfer.v1.endpoint.ObjectTransferStage\x12I\n\x05table\x18\x03 \x01(\x0e\x32:.yandex.cloud.datatransfer.v1.endpoint.ObjectTransferStage\x12O\n\x0bprimary_key\x18\x04 \x01(\x0e\x32:.yandex.cloud.datatransfer.v1.endpoint.ObjectTransferStage\x12Q\n\rfk_constraint\x18\x05 \x01(\x0e\x32:.yandex.cloud.datatransfer.v1.endpoint.ObjectTransferStage\x12R\n\x0e\x64\x65\x66\x61ult_values\x18\x06 \x01(\x0e\x32:.yandex.cloud.datatransfer.v1.endpoint.ObjectTransferStage\x12N\n\nconstraint\x18\x07 \x01(\x0e\x32:.yandex.cloud.datatransfer.v1.endpoint.ObjectTransferStage\x12I\n\x05index\x18\x08 \x01(\x0e\x32:.yandex.cloud.datatransfer.v1.endpoint.ObjectTransferStage\x12H\n\x04view\x18\t \x01(\x0e\x32:.yandex.cloud.datatransfer.v1.endpoint.ObjectTransferStage\x12L\n\x08\x66unction\x18\n \x01(\x0e\x32:.yandex.cloud.datatransfer.v1.endpoint.ObjectTransferStage\x12K\n\x07trigger\x18\x0b \x01(\x0e\x32:.yandex.cloud.datatransfer.v1.endpoint.ObjectTransferStage\x12H\n\x04type\x18\x0c \x01(\x0e\x32:.yandex.cloud.datatransfer.v1.endpoint.ObjectTransferStage\x12H\n\x04rule\x18\r \x01(\x0e\x32:.yandex.cloud.datatransfer.v1.endpoint.ObjectTransferStage\x12M\n\tcollation\x18\x0e \x01(\x0e\x32:.yandex.cloud.datatransfer.v1.endpoint.ObjectTransferStage\x12J\n\x06policy\x18\x0f \x01(\x0e\x32:.yandex.cloud.datatransfer.v1.endpoint.ObjectTransferStage\x12H\n\x04\x63\x61st\x18\x10 \x01(\x0e\x32:.yandex.cloud.datatransfer.v1.endpoint.ObjectTransferStage\x12U\n\x11materialized_view\x18\x11 \x01(\x0e\x32:.yandex.cloud.datatransfer.v1.endpoint.ObjectTransferStage\x12P\n\x0csequence_set\x18\x12 \x01(\x0e\x32:.yandex.cloud.datatransfer.v1.endpoint.ObjectTransferStage\"\x91\x01\n\x11OnPremisePostgres\x12\x0c\n\x04port\x18\x02 \x01(\x03\x12\x11\n\tsubnet_id\x18\x04 \x01(\t\x12\r\n\x05hosts\x18\x05 \x03(\t\x12@\n\x08tls_mode\x18\x06 \x01(\x0b\x32..yandex.cloud.datatransfer.v1.endpoint.TLSModeJ\x04\x08\x01\x10\x02J\x04\x08\x03\x10\x04\"\x8c\x01\n\x12PostgresConnection\x12\x18\n\x0emdb_cluster_id\x18\x01 \x01(\tH\x00\x12N\n\non_premise\x18\x02 \x01(\x0b\x32\x38.yandex.cloud.datatransfer.v1.endpoint.OnPremisePostgresH\x00\x42\x0c\n\nconnection\"\xb3\x03\n\x0ePostgresSource\x12M\n\nconnection\x18\x01 \x01(\x0b\x32\x39.yandex.cloud.datatransfer.v1.endpoint.PostgresConnection\x12\x10\n\x08\x64\x61tabase\x18\x02 \x01(\t\x12\x0c\n\x04user\x18\x03 \x01(\t\x12?\n\x08password\x18\x04 \x01(\x0b\x32-.yandex.cloud.datatransfer.v1.endpoint.Secret\x12\x16\n\x0einclude_tables\x18\x05 \x03(\t\x12\x16\n\x0e\x65xclude_tables\x18\x06 \x03(\t\x12\x1b\n\x13slot_byte_lag_limit\x18\x08 \x01(\x03\x12\x16\n\x0eservice_schema\x18\t \x01(\t\x12g\n\x18object_transfer_settings\x18\r \x01(\x0b\x32\x45.yandex.cloud.datatransfer.v1.endpoint.PostgresObjectTransferSettings\x12\x17\n\x0fsecurity_groups\x18\x0e \x03(\tJ\x04\x08\x07\x10\x08J\x04\x08\n\x10\r\"\xad\x02\n\x0ePostgresTarget\x12M\n\nconnection\x18\x01 \x01(\x0b\x32\x39.yandex.cloud.datatransfer.v1.endpoint.PostgresConnection\x12\x10\n\x08\x64\x61tabase\x18\x02 \x01(\t\x12\x0c\n\x04user\x18\x03 \x01(\t\x12?\n\x08password\x18\x04 \x01(\x0b\x32-.yandex.cloud.datatransfer.v1.endpoint.Secret\x12L\n\x0e\x63leanup_policy\x18\x05 \x01(\x0e\x32\x34.yandex.cloud.datatransfer.v1.endpoint.CleanupPolicy\x12\x17\n\x0fsecurity_groups\x18\x07 \x03(\tJ\x04\x08\x06\x10\x07\x42\xa7\x01\n)yandex.cloud.api.datatransfer.v1.endpointZRgithub.com/yandex-cloud/go-genproto/yandex/cloud/datatransfer/v1/endpoint;endpoint\xaa\x02%Yandex.Cloud.Datatransfer.V1.EndPointb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.datatransfer.v1.endpoint.postgres_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n)yandex.cloud.api.datatransfer.v1.endpointZRgithub.com/yandex-cloud/go-genproto/yandex/cloud/datatransfer/v1/endpoint;endpoint\252\002%Yandex.Cloud.Datatransfer.V1.EndPoint'
  _globals['_POSTGRESOBJECTTRANSFERSETTINGS']._serialized_start=148
  _globals['_POSTGRESOBJECTTRANSFERSETTINGS']._serialized_end=1598
  _globals['_ONPREMISEPOSTGRES']._serialized_start=1601
  _globals['_ONPREMISEPOSTGRES']._serialized_end=1746
  _globals['_POSTGRESCONNECTION']._serialized_start=1749
  _globals['_POSTGRESCONNECTION']._serialized_end=1889
  _globals['_POSTGRESSOURCE']._serialized_start=1892
  _globals['_POSTGRESSOURCE']._serialized_end=2327
  _globals['_POSTGRESTARGET']._serialized_start=2330
  _globals['_POSTGRESTARGET']._serialized_end=2631
# @@protoc_insertion_point(module_scope)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import google.protobuf.timestamp_pb2
import google.protobuf.wrappers_pb2
import sys
import typing

if sys.version_info >= (3, 10):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class Project(google.protobuf.message.Message):
    """A Project resource."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing.final
    class Settings(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        class _CommitMode:
            ValueType = typing.NewType("ValueType", builtins.int)
            V: typing_extensions.TypeAlias = ValueType

        class _CommitModeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[Project.Settings._CommitMode.ValueType], builtins.type):
            DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
            COMMIT_MODE_UNSPECIFIED: Project.Settings._CommitMode.ValueType  # 0
            STANDARD: Project.Settings._CommitMode.ValueType  # 1
            """Commit happens after the execution of a cell or group of cells or after completion with an error."""
            AUTO: Project.Settings._CommitMode.ValueType  # 2
            """Commit happens periodically.
            Also, automatic saving of state occurs when switching to another type of computing resource.
            """

        class CommitMode(_CommitMode, metaclass=_CommitModeEnumTypeWrapper): ...
        COMMIT_MODE_UNSPECIFIED: Project.Settings.CommitMode.ValueType  # 0
        STANDARD: Project.Settings.CommitMode.ValueType  # 1
        """Commit happens after the execution of a cell or group of cells or after completion with an error."""
        AUTO: Project.Settings.CommitMode.ValueType  # 2
        """Commit happens periodically.
        Also, automatic saving of state occurs when switching to another type of computing resource.
        """

        SERVICE_ACCOUNT_ID_FIELD_NUMBER: builtins.int
        SUBNET_ID_FIELD_NUMBER: builtins.int
        DATA_PROC_CLUSTER_ID_FIELD_NUMBER: builtins.int
        COMMIT_MODE_FIELD_NUMBER: builtins.int
        SECURITY_GROUP_IDS_FIELD_NUMBER: builtins.int
        service_account_id: builtins.str
        """ID of the service account, on whose behalf all operations with clusters will be performed."""
        subnet_id: builtins.str
        """ID of the subnet where the DataProc cluster resides.
        Currently only subnets created in the availability zone ru-central1-a are supported.
        """
        data_proc_cluster_id: builtins.str
        """ID of the DataProc cluster."""
        commit_mode: global___Project.Settings.CommitMode.ValueType
        """Commit mode that is assigned to the project."""
        @property
        def security_group_ids(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]:
            """Network interfaces security groups."""

        def __init__(
            self,
            *,
            service_account_id: builtins.str = ...,
            subnet_id: builtins.str = ...,
            data_proc_cluster_id: builtins.str = ...,
            commit_mode: global___Project.Settings.CommitMode.ValueType = ...,
            security_group_ids: collections.abc.Iterable[builtins.str] | None = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing.Literal["commit_mode", b"commit_mode", "data_proc_cluster_id", b"data_proc_cluster_id", "security_group_ids", b"security_group_ids", "service_account_id", b"service_account_id", "subnet_id", b"subnet_id"]) -> None: ...

    @typing.final
    class Limits(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        MAX_UNITS_PER_HOUR_FIELD_NUMBER: builtins.int
        MAX_UNITS_PER_EXECUTION_FIELD_NUMBER: builtins.int
        @property
        def max_units_per_hour(self) -> google.protobuf.wrappers_pb2.Int64Value:
            """The number of units that can be spent per hour."""

        @property
        def max_units_per_execution(self) -> google.protobuf.wrappers_pb2.Int64Value:
            """The number of units that can be spent on the one execution."""

        def __init__(
            self,
            *,
            max_units_per_hour: google.protobuf.wrappers_pb2.Int64Value | None = ...,
            max_units_per_execution: google.protobuf.wrappers_pb2.Int64Value | None = ...,
        ) -> None: ...
        def HasField(self, field_name: typing.Literal["max_units_per_execution", b"max_units_per_execution", "max_units_per_hour", b"max_units_per_hour"]) -> builtins.bool: ...
        def ClearField(self, field_name: typing.Literal["max_units_per_execution", b"max_units_per_execution", "max_units_per_hour", b"max_units_per_hour"]) -> None: ...

    ID_FIELD_NUMBER: builtins.int
    FOLDER_ID_FIELD_NUMBER: builtins.int
    CREATED_AT_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    SETTINGS_FIELD_NUMBER: builtins.int
    LIMITS_FIELD_NUMBER: builtins.int
    id: builtins.str
    """ID of the project."""
    folder_id: builtins.str
    """ID of the folder that the project belongs to."""
    name: builtins.str
    """Name of the project. 1-63 characters long."""
    description: builtins.str
    """Description of the project. 0-256 characters long."""
    @property
    def created_at(self) -> google.protobuf.timestamp_pb2.Timestamp: ...
    @property
    def settings(self) -> global___Project.Settings:
        """Settings of the project."""

    @property
    def limits(self) -> global___Project.Limits:
        """Limits of the project."""

    def __init__(
        self,
        *,
        id: builtins.str = ...,
        folder_id: builtins.str = ...,
        created_at: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        name: builtins.str = ...,
        description: builtins.str = ...,
        settings: global___Project.Settings | None = ...,
        limits: global___Project.Limits | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["created_at", b"created_at", "limits", b"limits", "settings", b"settings"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["created_at", b"created_at", "description", b"description", "folder_id", b"folder_id", "id", b"id", "limits", b"limits", "name", b"name", "settings", b"settings"]) -> None: ...

global___Project = Project



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.field_mask_pb2
import google.protobuf.internal.containers
import google.protobuf.message
import typing
import yandex.cloud.operation.operation_pb2
import yandex.cloud.serverless.eventrouter.v1.connector_pb2

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class GetConnectorRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CONNECTOR_ID_FIELD_NUMBER: builtins.int
    connector_id: builtins.str
    """ID of the connector to return."""
    def __init__(
        self,
        *,
        connector_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["connector_id", b"connector_id"]) -> None: ...

global___GetConnectorRequest = GetConnectorRequest

@typing.final
class ListConnectorsRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    BUS_ID_FIELD_NUMBER: builtins.int
    FOLDER_ID_FIELD_NUMBER: builtins.int
    PAGE_SIZE_FIELD_NUMBER: builtins.int
    PAGE_TOKEN_FIELD_NUMBER: builtins.int
    FILTER_FIELD_NUMBER: builtins.int
    bus_id: builtins.str
    """ID of the bus to list connectors in."""
    folder_id: builtins.str
    """ID of the folder to list connectors in."""
    page_size: builtins.int
    """The maximum number of results per response."""
    page_token: builtins.str
    """Page token. To get the next page of results, set `page_token` to the
    `next_page_token` returned by a previous list request.
    """
    filter: builtins.str
    """Supported fields for filter:
      name
      created_at
    """
    def __init__(
        self,
        *,
        bus_id: builtins.str = ...,
        folder_id: builtins.str = ...,
        page_size: builtins.int = ...,
        page_token: builtins.str = ...,
        filter: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["bus_id", b"bus_id", "container_id", b"container_id", "folder_id", b"folder_id"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["bus_id", b"bus_id", "container_id", b"container_id", "filter", b"filter", "folder_id", b"folder_id", "page_size", b"page_size", "page_token", b"page_token"]) -> None: ...
    def WhichOneof(self, oneof_group: typing.Literal["container_id", b"container_id"]) -> typing.Literal["bus_id", "folder_id"] | None: ...

global___ListConnectorsRequest = ListConnectorsRequest

@typing.final
class ListConnectorsResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CONNECTORS_FIELD_NUMBER: builtins.int
    NEXT_PAGE_TOKEN_FIELD_NUMBER: builtins.int
    next_page_token: builtins.str
    """Token for getting the next page of the list of results."""
    @property
    def connectors(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[yandex.cloud.serverless.eventrouter.v1.connector_pb2.Connector]:
        """List of connectors."""

    def __init__(
        self,
        *,
        connectors: collections.abc.Iterable[yandex.cloud.serverless.eventrouter.v1.connector_pb2.Connector] | None = ...,
        next_page_token: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["connectors", b"connectors", "next_page_token", b"next_page_token"]) -> None: ...

global___ListConnectorsResponse = ListConnectorsResponse

@typing.final
class CreateConnectorRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing.final
    class LabelsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing.Literal["key", b"key", "value", b"value"]) -> None: ...

    BUS_ID_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    LABELS_FIELD_NUMBER: builtins.int
    SOURCE_FIELD_NUMBER: builtins.int
    DELETION_PROTECTION_FIELD_NUMBER: builtins.int
    bus_id: builtins.str
    """ID of the bus to create a connector in."""
    name: builtins.str
    """Name of the connector."""
    description: builtins.str
    """Description of the connector."""
    deletion_protection: builtins.bool
    """Flag that disallow deletion of the connector."""
    @property
    def labels(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]:
        """Labels for the connector."""

    @property
    def source(self) -> yandex.cloud.serverless.eventrouter.v1.connector_pb2.Source:
        """Source of the connector."""

    def __init__(
        self,
        *,
        bus_id: builtins.str = ...,
        name: builtins.str = ...,
        description: builtins.str = ...,
        labels: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        source: yandex.cloud.serverless.eventrouter.v1.connector_pb2.Source | None = ...,
        deletion_protection: builtins.bool = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["source", b"source"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["bus_id", b"bus_id", "deletion_protection", b"deletion_protection", "description", b"description", "labels", b"labels", "name", b"name", "source", b"source"]) -> None: ...

global___CreateConnectorRequest = CreateConnectorRequest

@typing.final
class CreateConnectorMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CONNECTOR_ID_FIELD_NUMBER: builtins.int
    BUS_ID_FIELD_NUMBER: builtins.int
    connector_id: builtins.str
    """ID of the connector that is being created."""
    bus_id: builtins.str
    """ID of the bus that the connector is created in."""
    def __init__(
        self,
        *,
        connector_id: builtins.str = ...,
        bus_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["bus_id", b"bus_id", "connector_id", b"connector_id"]) -> None: ...

global___CreateConnectorMetadata = CreateConnectorMetadata

@typing.final
class UpdateConnectorRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing.final
    class LabelsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing.Literal["key", b"key", "value", b"value"]) -> None: ...

    CONNECTOR_ID_FIELD_NUMBER: builtins.int
    UPDATE_MASK_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    LABELS_FIELD_NUMBER: builtins.int
    DELETION_PROTECTION_FIELD_NUMBER: builtins.int
    connector_id: builtins.str
    """ID of the connector to update."""
    name: builtins.str
    """New name of the connector."""
    description: builtins.str
    """New description of the connector."""
    deletion_protection: builtins.bool
    """New flag that disallow deletion of the connector."""
    @property
    def update_mask(self) -> google.protobuf.field_mask_pb2.FieldMask:
        """Field mask that specifies which fields of the connector are going to be updated."""

    @property
    def labels(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]:
        """New labels of the connector."""

    def __init__(
        self,
        *,
        connector_id: builtins.str = ...,
        update_mask: google.protobuf.field_mask_pb2.FieldMask | None = ...,
        name: builtins.str = ...,
        description: builtins.str = ...,
        labels: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        deletion_protection: builtins.bool = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["update_mask", b"update_mask"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["connector_id", b"connector_id", "deletion_protection", b"deletion_protection", "description", b"description", "labels", b"labels", "name", b"name", "update_mask", b"update_mask"]) -> None: ...

global___UpdateConnectorRequest = UpdateConnectorRequest

@typing.final
class UpdateConnectorMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CONNECTOR_ID_FIELD_NUMBER: builtins.int
    connector_id: builtins.str
    """ID of the connector that is being updated."""
    def __init__(
        self,
        *,
        connector_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["connector_id", b"connector_id"]) -> None: ...

global___UpdateConnectorMetadata = UpdateConnectorMetadata

@typing.final
class DeleteConnectorRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CONNECTOR_ID_FIELD_NUMBER: builtins.int
    connector_id: builtins.str
    """ID of the connector to delete."""
    def __init__(
        self,
        *,
        connector_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["connector_id", b"connector_id"]) -> None: ...

global___DeleteConnectorRequest = DeleteConnectorRequest

@typing.final
class DeleteConnectorMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CONNECTOR_ID_FIELD_NUMBER: builtins.int
    connector_id: builtins.str
    """ID of the connector that is being deleted."""
    def __init__(
        self,
        *,
        connector_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["connector_id", b"connector_id"]) -> None: ...

global___DeleteConnectorMetadata = DeleteConnectorMetadata

@typing.final
class ListConnectorOperationsRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CONNECTOR_ID_FIELD_NUMBER: builtins.int
    PAGE_SIZE_FIELD_NUMBER: builtins.int
    PAGE_TOKEN_FIELD_NUMBER: builtins.int
    FILTER_FIELD_NUMBER: builtins.int
    connector_id: builtins.str
    """ID of the connector to list operations for."""
    page_size: builtins.int
    """The maximum number of results per response."""
    page_token: builtins.str
    """Page token. To get the next page of results, set `page_token` to the
    `next_page_token` returned by a previous list request.
    """
    filter: builtins.str
    """Supported attributes for filter:
      description
      created_at
      modified_at
      created_by
      done
    """
    def __init__(
        self,
        *,
        connector_id: builtins.str = ...,
        page_size: builtins.int = ...,
        page_token: builtins.str = ...,
        filter: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["connector_id", b"connector_id", "filter", b"filter", "page_size", b"page_size", "page_token", b"page_token"]) -> None: ...

global___ListConnectorOperationsRequest = ListConnectorOperationsRequest

@typing.final
class ListConnectorOperationsResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    OPERATIONS_FIELD_NUMBER: builtins.int
    NEXT_PAGE_TOKEN_FIELD_NUMBER: builtins.int
    next_page_token: builtins.str
    """Token for getting the next page of the list of results."""
    @property
    def operations(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[yandex.cloud.operation.operation_pb2.Operation]:
        """List of operations for the specified connector."""

    def __init__(
        self,
        *,
        operations: collections.abc.Iterable[yandex.cloud.operation.operation_pb2.Operation] | None = ...,
        next_page_token: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["next_page_token", b"next_page_token", "operations", b"operations"]) -> None: ...

global___ListConnectorOperationsResponse = ListConnectorOperationsResponse

@typing.final
class StartConnectorRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CONNECTOR_ID_FIELD_NUMBER: builtins.int
    connector_id: builtins.str
    """ID of the connector to start."""
    def __init__(
        self,
        *,
        connector_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["connector_id", b"connector_id"]) -> None: ...

global___StartConnectorRequest = StartConnectorRequest

@typing.final
class StartConnectorMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CONNECTOR_ID_FIELD_NUMBER: builtins.int
    connector_id: builtins.str
    """ID of the connector that is being started."""
    def __init__(
        self,
        *,
        connector_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["connector_id", b"connector_id"]) -> None: ...

global___StartConnectorMetadata = StartConnectorMetadata

@typing.final
class StopConnectorRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CONNECTOR_ID_FIELD_NUMBER: builtins.int
    connector_id: builtins.str
    """ID of the connector to stop."""
    def __init__(
        self,
        *,
        connector_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["connector_id", b"connector_id"]) -> None: ...

global___StopConnectorRequest = StopConnectorRequest

@typing.final
class StopConnectorMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CONNECTOR_ID_FIELD_NUMBER: builtins.int
    connector_id: builtins.str
    """ID of the connector that is being stopped."""
    def __init__(
        self,
        *,
        connector_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["connector_id", b"connector_id"]) -> None: ...

global___StopConnectorMetadata = StopConnectorMetadata



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import google.protobuf.timestamp_pb2
import sys
import typing
import yandex.cloud.compute.v1.hardware_generation_pb2

if sys.version_info >= (3, 10):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class Snapshot(google.protobuf.message.Message):
    """A Snapshot resource. For more information, see [Snapshots](/docs/compute/concepts/snapshot)."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    class _Status:
        ValueType = typing.NewType("ValueType", builtins.int)
        V: typing_extensions.TypeAlias = ValueType

    class _StatusEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[Snapshot._Status.ValueType], builtins.type):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
        STATUS_UNSPECIFIED: Snapshot._Status.ValueType  # 0
        CREATING: Snapshot._Status.ValueType  # 1
        """Snapshot is being created."""
        READY: Snapshot._Status.ValueType  # 2
        """Snapshot is ready to use."""
        ERROR: Snapshot._Status.ValueType  # 3
        """Snapshot encountered a problem and cannot operate."""
        DELETING: Snapshot._Status.ValueType  # 4
        """Snapshot is being deleted."""

    class Status(_Status, metaclass=_StatusEnumTypeWrapper): ...
    STATUS_UNSPECIFIED: Snapshot.Status.ValueType  # 0
    CREATING: Snapshot.Status.ValueType  # 1
    """Snapshot is being created."""
    READY: Snapshot.Status.ValueType  # 2
    """Snapshot is ready to use."""
    ERROR: Snapshot.Status.ValueType  # 3
    """Snapshot encountered a problem and cannot operate."""
    DELETING: Snapshot.Status.ValueType  # 4
    """Snapshot is being deleted."""

    @typing.final
    class LabelsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing.Literal["key", b"key", "value", b"value"]) -> None: ...

    ID_FIELD_NUMBER: builtins.int
    FOLDER_ID_FIELD_NUMBER: builtins.int
    CREATED_AT_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    LABELS_FIELD_NUMBER: builtins.int
    STORAGE_SIZE_FIELD_NUMBER: builtins.int
    DISK_SIZE_FIELD_NUMBER: builtins.int
    PRODUCT_IDS_FIELD_NUMBER: builtins.int
    STATUS_FIELD_NUMBER: builtins.int
    SOURCE_DISK_ID_FIELD_NUMBER: builtins.int
    HARDWARE_GENERATION_FIELD_NUMBER: builtins.int
    id: builtins.str
    """ID of the snapshot."""
    folder_id: builtins.str
    """ID of the folder that the snapshot belongs to."""
    name: builtins.str
    """Name of the snapshot. 1-63 characters long."""
    description: builtins.str
    """Description of the snapshot. 0-256 characters long."""
    storage_size: builtins.int
    """Size of the snapshot, specified in bytes.
    delta from prev snapshot from same disk
    """
    disk_size: builtins.int
    """Size of the disk when the snapshot was created, specified in bytes.
    at snapshot moment
    """
    status: global___Snapshot.Status.ValueType
    """Current status of the snapshot."""
    source_disk_id: builtins.str
    """ID of the source disk used to create this snapshot."""
    @property
    def created_at(self) -> google.protobuf.timestamp_pb2.Timestamp: ...
    @property
    def labels(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]:
        """Resource labels as `key:value` pairs. Maximum of 64 per resource."""

    @property
    def product_ids(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]:
        """License IDs that indicate which licenses are attached to this resource.
        License IDs are used to calculate additional charges for the use of the virtual machine.

        The correct license ID is generated by the platform. IDs are inherited by new resources created from this resource.

        If you know the license IDs, specify them when you create the image.
        For example, if you create a disk image using a third-party utility and load it into Object Storage, the license IDs will be lost.
        You can specify them in the [yandex.cloud.compute.v1.ImageService.Create] request.
        """

    @property
    def hardware_generation(self) -> yandex.cloud.compute.v1.hardware_generation_pb2.HardwareGeneration:
        """If specified, forces the same HardwareGeneration features to be applied to the instance
        created using this snapshot as source for the boot disk. Otherwise the current default will be used.
        """

    def __init__(
        self,
        *,
        id: builtins.str = ...,
        folder_id: builtins.str = ...,
        created_at: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        name: builtins.str = ...,
        description: builtins.str = ...,
        labels: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        storage_size: builtins.int = ...,
        disk_size: builtins.int = ...,
        product_ids: collections.abc.Iterable[builtins.str] | None = ...,
        status: global___Snapshot.Status.ValueType = ...,
        source_disk_id: builtins.str = ...,
        hardware_generation: yandex.cloud.compute.v1.hardware_generation_pb2.HardwareGeneration | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["created_at", b"created_at", "hardware_generation", b"hardware_generation"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["created_at", b"created_at", "description", b"description", "disk_size", b"disk_size", "folder_id", b"folder_id", "hardware_generation", b"hardware_generation", "id", b"id", "labels", b"labels", "name", b"name", "product_ids", b"product_ids", "source_disk_id", b"source_disk_id", "status", b"status", "storage_size", b"storage_size"]) -> None: ...

global___Snapshot = Snapshot
